/*
	XML Bible system for RunUO 2.0
	by Lokai
*/
using System;
using System.IO;
using System.Xml;
using System.Collections;
using Server;

namespace Server.Custom
{
	public static class TopicReader
	{
		private static int[,] m_ABOMINATION_OF_DESOLATION = new int[,] { 
		{ 27,8,9,14 },
		{ 27,8,23,26 },
		{ 27,9,26,27 },
		{ 27,11,29,31 },
		{ 27,12,11,11 },
		{ 40,24,15,28 },
		{ 41,13,14,23 },
		{ 42,21,20,24 } };
		private static int[,] m_ADOPTION = new int[,] { 
		{ 1,48,5,16 },
		{ 17,2,7,7 },
		{ 44,7,20,21 },
		{ 45,8,12,15 },
		{ 45,8,22,23 },
		{ 45,9,3,4 },
		{ 48,4,4,7 },
		{ 49,1,3,5 } };
		private static int[,] m_ADULTERY = new int[,] { 
		{ 2,20,14,14 },
		{ 20,6,20,29 },
		{ 40,5,28,28 },
		{ 40,19,9,9 },
		{ 46,5,9,11 },
		{ 46,6,9,10 },
		{ 52,4,3,7 } };
		private static int[,] m_SPIRITUAL_ADULTERY = new int[,] { 
		{ 24,3,6,9 },
		{ 28,1,2,2 },
		{ 28,4,11,13 },
		{ 46,6,18,20 },
		{ 66,17,5,5 },
		{ 66,18,3,3 } };
		private static int[,] m_ALCOHOL = new int[,] { 
		{ 3,10,8,11 },
		{ 5,14,26,26 },
		{ 19,104,14,15 },
		{ 20,31,6,7 },
		{ 40,26,29,29 },
		{ 42,10,33,34 },
		{ 43,2,1,10 },
		{ 54,5,23,23 },
		{ 20,23,29,35 },
		{ 20,31,4,5 },
		{ 23,5,11,12 },
		{ 48,5,19,21 },
		{ 49,5,18,18 },
		{ 54,3,2,3 } };
		private static int[,] m_ANGEL_OF_THE_LORD = new int[,] { 
		{ 1,16,6,14 },
		{ 1,22,4,18 },
		{ 2,3,1,5 },
		{ 4,22,22,35 },
		{ 7,6,11,24 },
		{ 12,19,35,35 },
		{ 13,21,11,30 } };
		private static int[,] m_ANGELS = new int[,] { 
		{ 1,19,1,1 },
		{ 18,38,4,7 },
		{ 19,34,7,7 },
		{ 40,18,10,10 },
		{ 42,20,34,36 },
		{ 58,1,5,7 },
		{ 58,13,2,2 },
		{ 66,5,11,11 },
		{ 27,8,15,16 },
		{ 27,10,13,21 },
		{ 27,12,1,1 },
		{ 42,1,11,19 },
		{ 66,12,7,8 } };
		private static int[,] m_CHERUBIM = new int[,] { 
		{ 1,3,24,24 },
		{ 2,25,18,22 },
		{ 10,22,10,11 },
		{ 19,99,1,1 },
		{ 26,1,4,14 },
		{ 26,10,14,14 } };
		private static int[,] m_HORSES = new int[,] { 
		{ 12,2,11,11 },
		{ 12,6,16,17 },
		{ 38,1,7,11 },
		{ 38,6,1,8 },
		{ 66,6,1,8 },
		{ 66,19,11,21 } };
		private static int[,] m_SERAPHIM = new int[,] { 
		{ 23,6,1,2 },
		{ 23,6,6,7 },
		{ 66,4,6,8 },
		{ 66,4,9,11 },
		{ 66,15,6,7 },
		{ 66,19,4,4 } };
		private static int[,] m_SEVEN_ANGELS = new int[,] { 
		{ 14,16,9,9 },
		{ 38,4,1,2 },
		{ 66,1,16,20 },
		{ 66,2,1,8 },
		{ 66,5,6,6 },
		{ 66,15,1,6 } };
		private static int[,] m_TWENTY_FOUR_ELDERS = new int[,] { 
		{ 66,4,4,4 },
		{ 66,4,9,11 },
		{ 66,5,8,10 },
		{ 66,5,11,11 },
		{ 66,11,15,18 },
		{ 66,19,4,4 } };
		private static int[,] m_ANGER = new int[,] { 
		{ 2,32,9,14 },
		{ 19,37,8,9 },
		{ 19,103,8,10 },
		{ 20,15,1,1 },
		{ 49,4,26,31 },
		{ 58,3,7,11 },
		{ 59,1,19,20 },
		{ 66,14,9,10 } };
		private static int[,] m_ANOINTING = new int[,] { 
		{ 2,29,4,9 },
		{ 9,9,27,27 },
		{ 9,16,13,13 },
		{ 19,133,2,2 },
		{ 26,28,14,14 },
		{ 40,6,17,17 },
		{ 59,5,13,15 },
		{ 62,2,27,27 } };
		private static int[,] m_ANTICHRIST = new int[,] { 
		{ 40,24,5,5 },
		{ 40,24,23,24 },
		{ 53,2,3,4 },
		{ 53,2,9,12 },
		{ 62,2,18,19 },
		{ 62,2,22,22 },
		{ 62,4,1,3 } };
		private static int[,] m_APOSTASY = new int[,] { 
		{ 5,13,1,3 },
		{ 43,6,66,69 },
		{ 48,1,6,9 },
		{ 53,2,3,4 },
		{ 54,6,20,21 },
		{ 55,4,1,4 },
		{ 61,2,12,15 },
		{ 62,2,19,19 } };
		private static int[,] m_FALSE_PROPHETS = new int[,] { 
		{ 5,13,1,5 },
		{ 23,8,20,20 },
		{ 24,5,30,31 },
		{ 24,23,9,40 },
		{ 40,24,23,24 },
		{ 66,2,20,20 } };
		private static int[,] m_FALSE_TEACHERS = new int[,] { 
		{ 44,20,29,31 },
		{ 54,1,5,7 },
		{ 55,4,3,4 },
		{ 56,1,10,16 },
		{ 61,2,1,3 },
		{ 61,2,12,17 } };
		private static int[,] m_APOSTLE = new int[,] { 
		{ 42,6,13,13 },
		{ 44,1,15,26 },
		{ 44,2,41,43 },
		{ 46,1,1,1 },
		{ 47,11,13,13 },
		{ 47,12,11,13 },
		{ 49,2,19,22 },
		{ 58,3,1,1 } };
		private static int[,] m_ARMAGEDDON = new int[,] { 
		{ 27,12,1,1 },
		{ 24,25,30,33 },
		{ 29,3,9,13 },
		{ 38,14,3,4 },
		{ 40,24,22,22 },
		{ 66,14,9,10 },
		{ 66,16,12,16 },
		{ 66,19,11,19 } };
		private static int[,] m_ARMOR_OF_GOD = new int[,] { 
		{ 9,17,38,39 },
		{ 19,18,35,35 },
		{ 23,59,16,17 },
		{ 45,13,12,12 },
		{ 47,6,7,7 },
		{ 49,6,10,20 },
		{ 52,5,8,8 },
		{ 66,1,16,16 } };
		private static int[,] m_ATONEMENT = new int[,] { 
		{ 3,16,3,3 },
		{ 3,17,11,11 },
		{ 3,23,26,32 },
		{ 19,35,13,13 },
		{ 44,27,9,9 },
		{ 45,3,23,25 },
		{ 45,5,11,11 },
		{ 58,9,6,12 } };
		private static int[,] m_BABYLON = new int[,] { 
		{ 1,11,1,9 },
		{ 12,25,1,21 },
		{ 13,9,1,1 },
		{ 19,137,8,9 },
		{ 27,4,30,30 },
		{ 40,1,17,17 },
		{ 66,17,3,6 },
		{ 66,18,1,5 } };
		private static int[,] m_BAPTISM = new int[,] { 
		{ 4,14,29,29 },
		{ 40,28,18,20 },
		{ 41,16,15,16 },
		{ 44,2,38,39 },
		{ 45,6,3,4 },
		{ 46,10,1,2 },
		{ 58,6,1,2 },
		{ 60,3,18,21 } };
		private static int[,] m_HOLY_SPIRIT_BAPTISM = new int[,] { 
		{ 40,3,11,11 },
		{ 40,3,16,16 },
		{ 44,2,1,4 },
		{ 44,2,38,38 },
		{ 44,10,44,48 },
		{ 46,12,12,13 } };
		private static int[,] m_WATER_BAPTISM = new int[,] { 
		{ 40,3,11,11 },
		{ 43,3,5,5 },
		{ 43,3,23,23 },
		{ 44,8,14,16 },
		{ 44,8,36,39 },
		{ 44,18,24,25 } };
		private static int[,] m_BEAST = new int[,] { 
		{ 27,7,1,8 },
		{ 66,13,1,8 },
		{ 66,13,11,17 },
		{ 66,13,18,18 },
		{ 66,14,9,11 },
		{ 66,16,12,14 },
		{ 66,17,1,18 },
		{ 66,19,17,21 } };
		private static int[,] m_BELIEVE = new int[,] { 
		{ 40,13,58,58 },
		{ 41,9,23,24 },
		{ 41,16,17,18 },
		{ 44,16,30,31 },
		{ 47,6,14,14 },
		{ 54,4,12,12 },
		{ 59,2,19,19 },
		{ 59,2,23,23 } };
		private static int[,] m_BIBLE_STUDY = new int[,] { 
		{ 19,119,105,10 },
		{ 20,1,1,6 },
		{ 20,2,4,5 },
		{ 23,28,10,10 },
		{ 44,17,10,11 },
		{ 55,2,15,15 },
		{ 60,3,15,15 },
		{ 61,3,18,18 } };
		private static int[,] m_BIRTHRIGHT_PROMISES = new int[,] { 
		{ 1,12,1,3 },
		{ 1,17,15,21 },
		{ 1,22,15,18 },
		{ 1,25,12,34 },
		{ 1,27,1,40 },
		{ 1,35,9,12 },
		{ 1,48,1,5 },
		{ 13,5,1,2 } };
		private static int[,] m_BLASPHEME = new int[,] { 
		{ 10,12,13,15 },
		{ 40,15,17,20 },
		{ 41,3,28,29 },
		{ 51,3,8,8 },
		{ 54,6,1,1 },
		{ 55,3,1,5 },
		{ 66,2,9,9 },
		{ 66,13,1,5 } };
		private static int[,] m_BLESSINGS_AND_CURSES = new int[,] { 
		{ 1,2,8,9 },
		{ 3,26,3,3 },
		{ 5,11,26,28 },
		{ 5,30,11,20 },
		{ 59,3,1,12 },
		{ 66,22,1,3 },
		{ 66,22,10,11 } };
		private static int[,] m_BLESSINGS = new int[,] { 
		{ 19,1,1,3 },
		{ 20,10,22,22 },
		{ 39,3,10,10 },
		{ 40,5,3,12 },
		{ 45,4,5,8 },
		{ 45,15,29,29 } };
		private static int[,] m_CURSES = new int[,] { 
		{ 1,3,16,19 },
		{ 20,26,2,2 },
		{ 23,3,1,12 },
		{ 39,2,1,3 },
		{ 39,4,4,6 },
		{ 45,8,19,22 } };
		private static int[,] m_BLINDED = new int[,] { 
		{ 23,29,9,14 },
		{ 23,44,18,20 },
		{ 40,13,10,17 },
		{ 43,6,44,44 },
		{ 45,1,18,25 },
		{ 46,2,14,14 },
		{ 47,4,3,4 } };
		private static int[,] m_BLOOD_OF_CHRIST = new int[,] { 
		{ 40,26,27,29 },
		{ 43,6,53,56 },
		{ 58,9,11,22 },
		{ 62,1,7,7 },
		{ 66,1,5,5 },
		{ 66,12,10,11 } };
		private static int[,] m_BLOOD_OF_FLESH = new int[,] { 
		{ 1,9,4,7 },
		{ 2,12,21,23 },
		{ 3,17,3,3 },
		{ 44,15,28,29 },
		{ 46,15,50,50 },
		{ 58,10,1,4 } };
		private static int[,] m_BOOK_OF_LIFE = new int[,] { 
		{ 2,32,31,33 },
		{ 27,12,1,1 },
		{ 66,3,5,5 },
		{ 66,13,8,8 },
		{ 66,17,8,8 },
		{ 66,20,11,15 },
		{ 66,21,27,27 },
		{ 66,22,18,19 } };
		private static int[,] m_BORN_AGAIN = new int[,] { 
		{ 43,1,12,13 },
		{ 43,3,3,8 },
		{ 45,8,29,29 },
		{ 46,15,20,23 },
		{ 46,15,35,55 },
		{ 47,5,1,2 },
		{ 60,1,22,23 },
		{ 62,3,1,2 } };
		private static int[,] m_HEBREW_CALENDAR = new int[,] { 
		{ 1,1,3,5 },
		{ 1,1,14,18 },
		{ 1,2,1,3 },
		{ 2,12,1,2 },
		{ 3,22,6,7 },
		{ 3,23,32,32 },
		{ 4,10,10,10 },
		{ 45,3,1,2 } };
		private static int[,] m_CALLED = new int[,] { 
		{ 40,22,14,14 },
		{ 42,14,25,33 },
		{ 43,6,44,44 },
		{ 43,15,16,16 },
		{ 45,8,28,30 },
		{ 46,1,26,29 },
		{ 46,7,17,24 },
		{ 61,1,10,10 } };
		private static int[,] m_CAPITAL_PUNISHMENT = new int[,] { 
		{ 1,9,4,6 },
		{ 2,21,12,17 },
		{ 3,24,17,17 },
		{ 4,35,15,19 },
		{ 4,35,20,21 },
		{ 4,35,26,31 },
		{ 5,13,1,11 },
		{ 45,13,1,5 } };
		private static int[,] m_CARNAL_CHARACTER = new int[,] { 
		{ 19,15,1,5 },
		{ 20,23,6,8 },
		{ 30,5,14,15 },
		{ 38,7,9,10 },
		{ 38,8,16,17 },
		{ 45,5,3,4 },
		{ 58,5,8,9 },
		{ 61,1,5,8 } };
		private static int[,] m_CHILDREARING = new int[,] { 
		{ 5,6,6,9 },
		{ 9,3,12,14 },
		{ 19,128,1,4 },
		{ 20,13,22,22 },
		{ 20,22,6,6 },
		{ 46,7,14,14 },
		{ 46,13,11,11 } };
		private static int[,] m_DISCIPLINE = new int[,] { 
		{ 19,103,8,10 },
		{ 20,3,11,12 },
		{ 20,13,24,24 },
		{ 20,22,15,15 },
		{ 20,23,13,14 },
		{ 49,6,4,4 } };
		private static int[,] m_CHILDREN = new int[,] { 
		{ 2,20,12,12 },
		{ 19,127,3,5 },
		{ 20,3,11,12 },
		{ 23,3,12,12 },
		{ 39,4,5,6 },
		{ 41,10,13,16 },
		{ 46,7,14,14 },
		{ 49,6,1,3 } };
		private static int[,] m_CHILDREN_OF_GOD = new int[,] { 
		{ 1,1,26,27 },
		{ 28,1,10,11 },
		{ 42,20,35,36 },
		{ 45,8,14,17 },
		{ 47,6,14,18 },
		{ 48,3,26,26 },
		{ 58,2,10,10 },
		{ 62,3,1,2 } };
		private static int[,] m_CHOSEN = new int[,] { 
		{ 40,22,14,14 },
		{ 41,13,20,20 },
		{ 43,15,16,16 },
		{ 46,1,26,29 },
		{ 49,1,3,4 },
		{ 53,2,13,13 },
		{ 60,2,9,9 },
		{ 66,17,14,14 } };
		private static int[,] m_CHRISTIAN = new int[,] { 
		{ 44,11,26,26 },
		{ 45,8,9,9 },
		{ 47,13,5,5 },
		{ 48,2,20,20 },
		{ 49,2,19,22 },
		{ 49,4,11,13 },
		{ 50,2,5,8 },
		{ 60,2,21,21 } };
		private static int[,] m_CHURCH = new int[,] { 
		{ 40,16,18,18 },
		{ 42,12,32,32 },
		{ 44,2,47,47 },
		{ 49,3,6,6 },
		{ 51,1,18,18 },
		{ 54,3,15,15 },
		{ 58,10,24,25 } };
		private static int[,] m_CHURCH_NAME = new int[,] { 
		{ 43,17,11,12 },
		{ 44,20,28,28 },
		{ 46,1,2,2 },
		{ 46,15,9,9 },
		{ 49,3,14,15 },
		{ 52,2,14,14 } };
		private static int[,] m_CHURCH_STRUCTURE = new int[,] { 
		{ 40,16,18,19 },
		{ 45,10,14,17 },
		{ 45,12,4,5 },
		{ 46,3,5,17 },
		{ 49,4,11,13 },
		{ 52,5,12,12 } };
		private static int[,] m_CIRCUMCISION = new int[,] { 
		{ 1,17,10,14 },
		{ 6,5,2,9 },
		{ 45,2,25,29 },
		{ 46,7,17,19 },
		{ 48,5,1,3 },
		{ 48,6,15,15 },
		{ 50,3,3,3 },
		{ 51,2,11,14 } };
		private static int[,] m_CLEAN_AND_UNCLEAN_MEAT = new int[,] { 
		{ 1,7,2,2 },
		{ 23,66,17,17 },
		{ 41,7,18,19 },
		{ 44,10,9,16 },
		{ 45,14,14,14 },
		{ 46,10,27,29 } };
		private static int[,] m_COMMANDMENTS = new int[,] { 
		{ 2,20,1,17 },
		{ 40,15,8,9 },
		{ 40,19,16,19 },
		{ 40,22,34,40 },
		{ 43,13,34,35 },
		{ 45,13,8,10 },
		{ 62,2,3,4 } };
		private static int[,] m_COMMITMENT = new int[,] { 
		{ 8,1,16,17 },
		{ 42,9,57,62 },
		{ 42,14,25,33 },
		{ 46,9,24,27 },
		{ 50,3,12,14 },
		{ 55,1,13,14 },
		{ 58,6,9,12 },
		{ 58,13,5,6 } };
		private static int[,] m_COMPASSION = new int[,] { 
		{ 2,33,19,19 },
		{ 19,86,15,15 },
		{ 25,3,22,22 },
		{ 40,9,35,36 },
		{ 41,6,34,34 },
		{ 48,5,22,23 },
		{ 58,5,1,2 },
		{ 59,5,11,11 } };
		private static int[,] m_CONVERSION = new int[,] { 
		{ 4,14,29,29 },
		{ 43,7,39,39 },
		{ 43,14,15,17 },
		{ 44,2,38,38 },
		{ 44,3,19,19 },
		{ 45,8,9,9 },
		{ 45,12,2,2 },
		{ 46,2,9,14 } };
		private static int[,] m_CORRECTION = new int[,] { 
		{ 5,8,5,5 },
		{ 19,103,8,10 },
		{ 19,119,67,67 },
		{ 20,3,11,12 },
		{ 20,29,1,1 },
		{ 24,2,19,19 },
		{ 24,24,3,5 },
		{ 58,12,3,11 } };
		private static int[,] m_COUNSEL = new int[,] { 
		{ 10,16,23,23 },
		{ 19,1,1,1 },
		{ 19,73,24,24 },
		{ 20,11,14,14 },
		{ 20,13,10,10 },
		{ 20,18,13,13 },
		{ 47,8,8,11 },
		{ 60,3,15,15 } };
		private static int[,] m_COURAGE = new int[,] { 
		{ 2,14,13,14 },
		{ 5,31,3,8 },
		{ 6,1,5,7 },
		{ 9,17,45,50 },
		{ 42,21,1,4 },
		{ 46,16,13,13 },
		{ 55,1,7,7 },
		{ 66,21,8,8 } };
		private static int[,] m_COVENANT = new int[,] { 
		{ 1,9,8,17 },
		{ 1,12,1,3 },
		{ 2,31,13,17 },
		{ 9,18,1,3 },
		{ 10,7,2,17 },
		{ 27,9,27,27 } };
		private static int[,] m_NEW_COVENANT = new int[,] { 
		{ 23,59,21,21 },
		{ 24,31,31,34 },
		{ 26,11,17,20 },
		{ 48,4,21,31 },
		{ 58,8,6,6 },
		{ 58,8,7,13 } };
		private static int[,] m_OLD_COVENANT = new int[,] { 
		{ 2,19,5,6 },
		{ 2,24,1,8 },
		{ 5,4,13,13 },
		{ 48,4,21,31 },
		{ 58,8,13,13 },
		{ 58,9,1,1 } };
		private static int[,] m_COVET = new int[,] { 
		{ 2,20,17,17 },
		{ 11,21,1,16 },
		{ 20,14,30,30 },
		{ 42,12,13,15 },
		{ 44,20,32,35 },
		{ 45,7,7,7 },
		{ 46,6,9,10 },
		{ 59,4,1,2 } };
		private static int[,] m_CREATION = new int[,] { 
		{ 1,1,1,26 },
		{ 5,4,19,19 },
		{ 18,38,4,7 },
		{ 19,148,1,6 },
		{ 43,1,1,3 },
		{ 45,8,19,23 },
		{ 47,4,18,18 },
		{ 58,1,1,3 } };
		private static int[,] m_CROSS = new int[,] { 
		{ 40,16,24,25 },
		{ 46,1,17,17 },
		{ 48,6,14,14 },
		{ 49,2,14,16 },
		{ 50,2,5,8 },
		{ 51,1,19,20 },
		{ 51,2,13,14 },
		{ 58,12,1,2 } };
		private static int[,] m_DAY_OF_THE_LORD = new int[,] { 
		{ 23,34,8,8 },
		{ 44,2,16,21 },
		{ 30,5,18,20 },
		{ 38,14,1,4 },
		{ 39,4,4,6 },
		{ 52,5,1,3 },
		{ 66,1,10,10 },
		{ 66,6,15,17 } };
		private static int[,] m_DEACONS = new int[,] { 
		{ 40,23,11,11 },
		{ 41,10,43,43 },
		{ 44,6,1,6 },
		{ 45,16,1,2 },
		{ 46,3,5,5 },
		{ 50,1,1,1 },
		{ 52,3,1,2 },
		{ 54,3,8,13 } };
		private static int[,] m_DEATH = new int[,] { 
		{ 1,2,16,17 },
		{ 19,6,5,5 },
		{ 19,116,15,15 },
		{ 21,3,18,20 },
		{ 21,9,5,6 },
		{ 26,18,4,20 },
		{ 58,9,27,27 },
		{ 59,4,13,14 } };
		private static int[,] m_DEBT = new int[,] { 
		{ 2,22,25,27 },
		{ 5,15,1,6 },
		{ 5,15,7,11 },
		{ 5,23,19,20 },
		{ 16,5,1,13 },
		{ 20,22,26,26 },
		{ 40,6,12,12 },
		{ 45,8,12,13 } };
		private static int[,] m_DECEIVE = new int[,] { 
		{ 24,17,9,10 },
		{ 40,13,22,22 },
		{ 43,6,44,44 },
		{ 47,11,12,13 },
		{ 49,5,6,7 },
		{ 54,2,13,14 },
		{ 59,1,26,26 },
		{ 66,12,9,9 } };
		private static int[,] m_DELIVERANCE = new int[,] { 
		{ 2,12,40,42 },
		{ 42,4,16,21 },
		{ 42,11,1,4 },
		{ 45,8,18,21 },
		{ 45,11,26,27 },
		{ 48,1,3,4 },
		{ 52,1,9,10 },
		{ 61,2,4,9 } };
		private static int[,] m_DEMONS = new int[,] { 
		{ 40,12,43,45 },
		{ 42,4,33,35 },
		{ 42,8,26,39 },
		{ 42,13,10,16 },
		{ 42,24,39,39 },
		{ 44,19,11,16 },
		{ 49,6,12,12 },
		{ 59,2,19,19 } };
		private static int[,] m_PUNISHMENT = new int[,] { 
		{ 23,14,12,15 },
		{ 40,8,28,29 },
		{ 61,2,4,4 },
		{ 66,20,1,3 },
		{ 66,20,7,10 } };
		private static int[,] m_DEPRESSION = new int[,] { 
		{ 11,19,1,4 },
		{ 19,23,1,4 },
		{ 19,77,1,13 },
		{ 20,12,25,25 },
		{ 20,25,28,28 },
		{ 24,20,7,18 },
		{ 47,4,16,16 },
		{ 49,4,25,32 } };
		private static int[,] m_DISCIPLE = new int[,] { 
		{ 40,9,37,38 },
		{ 40,10,1,1 },
		{ 40,28,19,20 },
		{ 42,6,12,16 },
		{ 42,14,26,33 },
		{ 43,8,31,31 },
		{ 44,6,7,7 },
		{ 44,11,26,26 } };
		private static int[,] m_DISFELLOWSHIP = new int[,] { 
		{ 4,16,26,26 },
		{ 43,20,22,23 },
		{ 45,16,17,17 },
		{ 46,5,4,5 },
		{ 53,3,6,6 },
		{ 53,3,14,15 },
		{ 54,1,18,20 },
		{ 54,6,3,5 } };
		private static int[,] m_DIVISION = new int[,] { 
		{ 20,6,16,19 },
		{ 43,7,43,43 },
		{ 43,10,12,12 },
		{ 45,16,17,17 },
		{ 46,1,10,13 },
		{ 46,3,3,3 },
		{ 46,11,17,19 } };
		private static int[,] m_DIVORCE = new int[,] { 
		{ 39,2,13,16 },
		{ 40,1,18,20 },
		{ 40,5,31,32 },
		{ 40,19,3,10 },
		{ 45,7,2,3 },
		{ 46,7,10,14 },
		{ 46,7,15,16 } };
		private static int[,] m_DOCTRINE = new int[,] { 
		{ 43,7,16,17 },
		{ 54,1,3,4 },
		{ 54,4,6,7 },
		{ 55,4,3,4 },
		{ 58,6,1,2 },
		{ 61,3,14,16 },
		{ 63,10,11,2 },
		{ 65,1,3,4 } };
		private static int[,] m_DRESS_AND_GROOMING = new int[,] { 
		{ 1,24,47,53 },
		{ 5,14,1,2 },
		{ 12,9,30,30 },
		{ 26,16,8,14 },
		{ 46,11,14,15 },
		{ 46,12,23,23 },
		{ 54,2,9,10 },
		{ 60,3,3,6 } };
		private static int[,] m_ELDERS = new int[,] { 
		{ 44,20,28,28 },
		{ 46,4,1,5 },
		{ 46,9,13,14 },
		{ 45,10,14,15 },
		{ 49,4,11,15 },
		{ 54,3,1,7 },
		{ 56,1,5,9 },
		{ 60,5,1,4 } };
		private static int[,] m_ELIJAH = new int[,] { 
		{ 11,17,19,1 },
		{ 12,2,8,11 },
		{ 14,21,12,15 },
		{ 39,4,4,6 },
		{ 40,17,11,12 },
		{ 41,1,1,8 },
		{ 43,1,19,23 } };
		private static int[,] m_ENDURANCE = new int[,] { 
		{ 40,10,22,22 },
		{ 42,9,62,62 },
		{ 46,13,4,7 },
		{ 48,6,9,10 },
		{ 55,2,1,3 },
		{ 58,6,13,15 },
		{ 58,12,1,1 },
		{ 66,3,10,10 } };
		private static int[,] m_ENEMY = new int[,] { 
		{ 2,23,4,5 },
		{ 20,27,6,6 },
		{ 40,5,43,45 },
		{ 45,5,8,10 },
		{ 45,12,17,21 },
		{ 46,15,25,26 },
		{ 53,3,14,15 },
		{ 59,4,4,4 } };
		private static int[,] m_IMMORTALITY = new int[,] { 
		{ 23,57,15,15 },
		{ 40,19,16,16 },
		{ 43,3,16,17 },
		{ 43,6,54,54 },
		{ 45,2,6,7 },
		{ 45,6,23,23 },
		{ 54,6,13,16 } };
		private static int[,] m_EVANGELISM = new int[,] { 
		{ 40,5,14,16 },
		{ 40,28,19,20 },
		{ 43,4,35,35 },
		{ 44,8,4,4 },
		{ 44,21,8,9 },
		{ 45,15,18,19 },
		{ 55,2,24,25 },
		{ 55,4,5,5 } };
		private static int[,] m_EVIL = new int[,] { 
		{ 1,3,1,7 },
		{ 1,6,5,7 },
		{ 19,23,4,4 },
		{ 19,37,7,11 },
		{ 23,5,20,20 },
		{ 30,5,14,15 },
		{ 40,6,9,13 },
		{ 45,12,17,17 } };
		private static int[,] m_FAITH = new int[,] { 
		{ 40,13,58,58 },
		{ 41,9,23,24 },
		{ 45,14,23,23 },
		{ 47,5,7,7 },
		{ 49,2,8,8 },
		{ 58,12,2,2 },
		{ 59,2,17,20 } };
		private static int[,] m_FAITHFUL = new int[,] { 
		{ 19,119,89,90 },
		{ 20,27,6,6 },
		{ 27,6,4,4 },
		{ 40,25,21,21 },
		{ 42,16,10,11 },
		{ 48,5,22,23 },
		{ 66,2,10,10 } };
		private static int[,] m_FALSE_CHRIST = new int[,] { 
		{ 27,7,8,19 },
		{ 27,8,9,12 },
		{ 27,11,21,45 },
		{ 53,2,3,4 },
		{ 53,2,5,12 },
		{ 66,13,11,18 },
		{ 66,19,20,20 } };
		private static int[,] m_FAMINE = new int[,] { 
		{ 1,47,13,26 },
		{ 13,21,11,13 },
		{ 19,33,18,19 },
		{ 26,5,11,17 },
		{ 30,8,11,11 },
		{ 40,24,4,8 },
		{ 45,8,35,39 },
		{ 66,18,8,8 } };
		private static int[,] m_FASTING = new int[,] { 
		{ 3,23,27,32 },
		{ 5,9,9,18 },
		{ 15,8,21,23 },
		{ 23,58,3,12 },
		{ 32,3,5,10 },
		{ 40,6,16,18 },
		{ 41,2,18,20 },
		{ 44,9,9,9 } };
		private static int[,] m_FATHER = new int[,] { 
		{ 1,2,23,24 },
		{ 2,20,12,12 },
		{ 20,20,20,20 },
		{ 39,4,4,6 },
		{ 40,15,3,6 },
		{ 42,14,26,27 },
		{ 49,6,4,4 },
		{ 54,5,1,2 },
		{ 1,1,26,26 },
		{ 19,110,1,1 },
		{ 41,15,34,34 },
		{ 43,1,1,2 },
		{ 46,8,6,6 },
		{ 49,3,14,15 },
		{ 58,7,1,1 },
		{ 62,5,7,8 } };
		private static int[,] m_FEAR = new int[,] { 
		{ 2,14,13,13 },
		{ 19,23,1,6 },
		{ 42,12,32,32 },
		{ 45,13,7,7 },
		{ 55,1,7,7 },
		{ 58,13,6,6 },
		{ 62,4,18,18 },
		{ 65,1,22,23 } };
		private static int[,] m_FEAR_OF_GOD = new int[,] { 
		{ 19,34,11,14 },
		{ 20,1,7,7 },
		{ 21,12,13,14 },
		{ 40,10,28,28 },
		{ 58,10,31,31 },
		{ 60,2,17,17 } };
		private static int[,] m_FEAST = new int[,] { 
		{ 1,1,14,14 },
		{ 2,31,12,13 },
		{ 3,23,3,3 },
		{ 5,12,5,7 },
		{ 5,16,16,17 },
		{ 23,1,12,15 },
		{ 23,25,6,8 },
		{ 51,2,16,17 } };
		private static int[,] m_FIRSTBORN = new int[,] { 
		{ 1,4,4,4 },
		{ 1,48,8,20 },
		{ 2,13,15,15 },
		{ 4,3,12,13 },
		{ 5,15,19,23 },
		{ 5,21,15,17 },
		{ 51,1,15,18 },
		{ 58,12,22,23 } };
		private static int[,] m_FIRSTFRUITS = new int[,] { 
		{ 2,23,14,19 },
		{ 2,34,22,23 },
		{ 3,23,9,11 },
		{ 5,26,1,11 },
		{ 45,8,22,23 },
		{ 46,15,20,23 },
		{ 59,1,17,18 },
		{ 66,14,1,5 } };
		private static int[,] m_FOOT_WASHING = new int[,] { 
		{ 1,18,1,5 },
		{ 1,24,32,32 },
		{ 1,43,24,24 },
		{ 9,25,40,42 },
		{ 19,58,9,11 },
		{ 42,7,36,50 },
		{ 43,13,1,15 },
		{ 54,5,9,10 } };
		private static int[,] m_FOREKNEW = new int[,] { 
		{ 23,44,28,28 },
		{ 24,1,4,5 },
		{ 44,2,23,23 },
		{ 45,8,29,30 },
		{ 45,11,1,3 },
		{ 53,2,13,13 },
		{ 55,1,8,9 },
		{ 60,1,2,2 } };
		private static int[,] m_FOREVER = new int[,] { 
		{ 1,3,22,23 },
		{ 5,15,16,17 },
		{ 10,7,12,17 },
		{ 23,9,6,7 },
		{ 27,7,18,18 },
		{ 65,1,12,13 },
		{ 66,11,15,15 } };
		private static int[,] m_FORGIVENESS = new int[,] { 
		{ 23,1,18,20 },
		{ 40,6,9,15 },
		{ 40,18,21,22 },
		{ 40,18,23,35 },
		{ 42,17,3,3 },
		{ 42,23,34,34 },
		{ 49,1,7,8 },
		{ 51,3,12,13 } };
		private static int[,] m_FORSAKE = new int[,] { 
		{ 5,4,30,31 },
		{ 5,31,6,8 },
		{ 14,15,1,2 },
		{ 23,55,6,7 },
		{ 41,15,34,34 },
		{ 42,5,11,11 },
		{ 47,4,8,9 },
		{ 58,10,24,25 } };
		private static int[,] m_FRIENDSHIP = new int[,] { 
		{ 10,1,25,26 },
		{ 20,17,17,17 },
		{ 20,18,24,24 },
		{ 20,22,24,25 },
		{ 20,27,5,6 },
		{ 43,15,13,15 },
		{ 59,2,23,23 },
		{ 59,4,4,4 } };
		private static int[,] m_GLORY = new int[,] { 
		{ 2,15,1,2 },
		{ 23,60,1,3 },
		{ 24,9,23,24 },
		{ 42,2,8,14 },
		{ 44,12,20,23 },
		{ 46,5,6,7 },
		{ 46,11,14,15 },
		{ 66,21,23,23 } };
		private static int[,] m_GLUTTONY = new int[,] { 
		{ 5,21,18,21 },
		{ 20,23,1,3 },
		{ 20,28,7,7 },
		{ 21,10,16,17 },
		{ 42,7,33,34 },
		{ 45,13,12,14 },
		{ 48,5,16,17 },
		{ 50,3,17,19 } };
		private static int[,] m_GOD = new int[,] { 
		{ 19,90,1,2 },
		{ 23,46,8,11 },
		{ 26,33,11,11 },
		{ 40,28,19,19 },
		{ 43,4,24,24 },
		{ 59,1,13,13 },
		{ 62,4,12,12 },
		{ 62,5,7,8 } };
		private static int[,] m_MAJESTY_OF_CHRIST = new int[,] { 
		{ 13,29,10,12 },
		{ 18,38,39,39 },
		{ 19,50,12,15 },
		{ 23,40,10,31 },
		{ 23,55,8,9 },
		{ 45,11,33,33 },
		{ 5,6,4,4 },
		{ 23,45,18,19 },
		{ 43,17,20,23 },
		{ 45,12,4,5 },
		{ 46,8,6,6 },
		{ 46,12,12,14 },
		{ 20,21,1,1 },
		{ 23,40,15,17 },
		{ 27,4,17,35 },
		{ 44,17,26,26 },
		{ 66,1,4,6 },
		{ 1,1,26,26 },
		{ 23,60,1,3 },
		{ 43,10,33,36 },
		{ 46,15,49,49 },
		{ 62,3,1,2 },
		{ 19,110,1,1 },
		{ 27,7,13,14 },
		{ 43,1,1,2 },
		{ 46,1,3,3 },
		{ 46,15,24,28 },
		{ 66,21,22,23 },
		{ 1,1,31,31 },
		{ 1,3,1,7 },
		{ 19,14,1,3 },
		{ 19,107,8,9 },
		{ 40,19,16,17 },
		{ 45,2,3,4 },
		{ 48,5,22,23 },
		{ 52,5,21,21 } };
		private static int[,] m_GOSPEL = new int[,] { 
		{ 23,55,1,3 },
		{ 30,8,11,12 },
		{ 40,24,14,14 },
		{ 42,2,10,11 },
		{ 45,10,14,18 },
		{ 48,1,6,7 },
		{ 66,11,3,6 },
		{ 66,14,6,7 } };
		private static int[,] m_GOSSIP = new int[,] { 
		{ 3,19,16,16 },
		{ 19,64,1,4 },
		{ 20,11,13,13 },
		{ 20,16,27,28 },
		{ 20,25,9,9 },
		{ 20,26,20,22 },
		{ 59,1,26,26 },
		{ 61,2,9,10 } };
		private static int[,] m_GOVERNMENT_OF_GOD = new int[,] { 
		{ 23,2,2,4 },
		{ 23,9,6,7 },
		{ 40,23,1,3 },
		{ 47,5,20,20 },
		{ 50,3,20,20 },
		{ 60,2,17,17 } };
		private static int[,] m_GOVERNMENT_OF_MAN = new int[,] { 
		{ 21,8,2,2 },
		{ 45,13,1,7 },
		{ 54,2,1,2 },
		{ 56,3,1,1 },
		{ 60,2,13,14 },
		{ 60,2,18,21 } };
		private static int[,] m_GRACE = new int[,] { 
		{ 23,55,6,7 },
		{ 45,6,14,15 },
		{ 45,8,1,4 },
		{ 47,12,7,9 },
		{ 49,2,4,9 },
		{ 56,3,4,5 },
		{ 60,4,10,10 },
		{ 61,3,18,18 } };
		private static int[,] m_HARVEST = new int[,] { 
		{ 2,23,14,19 },
		{ 2,34,21,22 },
		{ 28,8,7,10 },
		{ 40,13,36,43 },
		{ 42,10,1,2 },
		{ 43,4,35,38 },
		{ 46,3,5,17 },
		{ 66,14,14,20 } };
		private static int[,] m_HEALING = new int[,] { 
		{ 2,15,25,26 },
		{ 4,21,4,9 },
		{ 19,103,3,3 },
		{ 40,9,18,22 },
		{ 44,19,11,12 },
		{ 59,5,13,15 },
		{ 60,2,21,24 },
		{ 66,22,1,2 } };
		private static int[,] m_HEALTH = new int[,] { 
		{ 3,3,17,17 },
		{ 3,13,45,46 },
		{ 20,3,1,2 },
		{ 20,3,7,8 },
		{ 20,17,22,22 },
		{ 20,25,27,27 },
		{ 54,4,8,8 },
		{ 54,5,23,23 } };
		private static int[,] m_HEART = new int[,] { 
		{ 5,6,5,6 },
		{ 9,16,7,7 },
		{ 20,17,22,22 },
		{ 20,23,6,8 },
		{ 24,17,9,9 },
		{ 24,31,33,34 },
		{ 40,12,33,37 },
		{ 44,13,22,23 } };
		private static int[,] m_HEAVEN = new int[,] { 
		{ 5,26,15,15 },
		{ 23,14,13,13 },
		{ 40,5,12,12 },
		{ 43,3,13,13 },
		{ 44,2,29,34 },
		{ 47,12,2,2 },
		{ 60,3,21,22 },
		{ 66,5,10,10 } };
		private static int[,] m_HEAVENLY_SIGNS = new int[,] { 
		{ 23,24,17,20 },
		{ 23,64,1,4 },
		{ 29,2,10,10 },
		{ 29,2,30,31 },
		{ 36,1,14,17 },
		{ 40,24,29,29 },
		{ 42,21,11,25 },
		{ 66,6,12,17 } };
		private static int[,] m_HEIRS = new int[,] { 
		{ 45,8,16,17 },
		{ 48,3,29,29 },
		{ 48,4,1,7 },
		{ 49,3,1,6 },
		{ 58,1,1,2 },
		{ 59,2,5,5 },
		{ 60,3,7,7 },
		{ 66,21,7,7 } };
		private static int[,] m_GEHENNA = new int[,] { 
		{ 40,5,21,22 },
		{ 40,5,27,30 },
		{ 40,10,28,28 },
		{ 40,23,15,33 },
		{ 41,9,43,48 },
		{ 59,3,6,6 } };
		private static int[,] m_HADES = new int[,] { 
		{ 40,16,18,18 },
		{ 42,16,19,31 },
		{ 44,2,25,31 },
		{ 46,15,54,55 },
		{ 66,6,7,8 },
		{ 66,20,13,14 } };
		private static int[,] m_SHEOL = new int[,] { 
		{ 19,16,10,10 },
		{ 23,14,9,9 },
		{ 23,14,11,11 },
		{ 23,38,17,18 },
		{ 24,8,1,1 },
		{ 32,2,2,2 },
		{ 61,2,4,4 } };
		private static int[,] m_HOLIDAYS = new int[,] { 
		{ 5,12,29,32 },
		{ 11,12,32,33 },
		{ 19,16,4,4 },
		{ 24,10,2,5 },
		{ 26,8,13,18 },
		{ 40,15,8,9 },
		{ 45,12,1,2 },
		{ 48,4,8,9 } };
		private static int[,] m_HOLY = new int[,] { 
		{ 2,3,2,5 },
		{ 2,19,5,6 },
		{ 3,10,9,11 },
		{ 46,7,14,14 },
		{ 58,9,2,3 },
		{ 60,1,15,16 },
		{ 60,2,5,9 },
		{ 66,20,6,6 } };
		private static int[,] m_HOLY_SPIRIT = new int[,] { 
		{ 40,1,18,20 },
		{ 43,4,24,24 },
		{ 44,5,32,32 },
		{ 44,8,14,25 },
		{ 45,8,16,16 },
		{ 45,8,23,27 },
		{ 48,5,22,23 },
		{ 49,4,29,30 } };
		private static int[,] m_INDWELLING = new int[,] { 
		{ 43,7,39,39 },
		{ 43,14,17,17 },
		{ 44,2,1,4 },
		{ 45,8,9,11 },
		{ 47,4,16,16 },
		{ 54,4,14,14 } };
		private static int[,] m_INSPIRATION = new int[,] { 
		{ 40,13,14,17 },
		{ 40,16,13,17 },
		{ 43,14,26,26 },
		{ 45,8,14,14 },
		{ 46,2,9,11 },
		{ 61,1,20,21 } };
		private static int[,] m_HOMOSEXUALITY = new int[,] { 
		{ 1,2,24,24 },
		{ 1,19,4,5 },
		{ 3,18,22,22 },
		{ 5,22,5,5 },
		{ 45,1,26,27 },
		{ 46,6,9,11 },
		{ 54,1,8,11 } };
		private static int[,] m_HONESTY = new int[,] { 
		{ 5,25,13,16 },
		{ 20,10,9,9 },
		{ 20,13,11,11 },
		{ 20,20,17,17 },
		{ 20,21,6,6 },
		{ 20,28,6,6 },
		{ 44,24,16,16 } };
		private static int[,] m_HOPE = new int[,] { 
		{ 19,39,7,7 },
		{ 24,29,10,11 },
		{ 45,8,24,25 },
		{ 46,15,19,19 },
		{ 51,1,27,27 },
		{ 50,1,3,6 },
		{ 58,6,17,20 },
		{ 60,3,15,15 } };
		private static int[,] m_HOSPITALITY = new int[,] { 
		{ 18,31,32,32 },
		{ 23,58,6,7 },
		{ 40,25,31,46 },
		{ 42,10,38,42 },
		{ 42,14,12,14 },
		{ 54,3,1,4 },
		{ 54,5,9,10 },
		{ 58,13,1,2 } };
		private static int[,] m_HUMILITY = new int[,] { 
		{ 23,66,1,2 },
		{ 40,18,1,5 },
		{ 42,14,7,10 },
		{ 42,14,11,11 },
		{ 45,12,3,3 },
		{ 50,2,3,4 },
		{ 50,2,5,8 },
		{ 60,5,5,7 } };
		private static int[,] m_IDOLATRY = new int[,] { 
		{ 2,20,4,6 },
		{ 2,32,1,6 },
		{ 24,10,1,5 },
		{ 44,15,19,21 },
		{ 46,5,9,13 },
		{ 48,5,19,21 },
		{ 66,13,11,15 },
		{ 66,22,14,15 } };
		private static int[,] m_ISRAEL = new int[,] { 
		{ 1,32,27,28 },
		{ 48,3,26,29 },
		{ 48,6,16,16 },
		{ 58,8,7,13 },
		{ 59,1,1,1 },
		{ 66,7,4,8 },
		{ 66,21,9,14 },
		{ 12,17,24,24 },
		{ 23,11,11,11 },
		{ 26,34,23,24 },
		{ 26,37,16,25 },
		{ 30,5,1,3 } };
		private static int[,] m_CHRIST_OF_ISRAEL = new int[,] { 
		{ 43,1,14,14 },
		{ 44,10,42,42 },
		{ 45,8,34,34 },
		{ 49,1,22,23 },
		{ 58,4,15,15 },
		{ 58,13,8,8 },
		{ 60,2,21,25 },
		{ 62,5,7,8 } };
		private static int[,] m_CREATOR = new int[,] { 
		{ 23,45,18,18 },
		{ 43,1,1,3 },
		{ 46,8,6,6 },
		{ 49,3,9,9 },
		{ 51,1,16,16 },
		{ 58,1,1,2 } };
		private static int[,] m_MELCHIZEDEK = new int[,] { 
		{ 1,14,18,20 },
		{ 19,110,4,4 },
		{ 58,6,19,20 },
		{ 58,7,1,3 },
		{ 58,7,9,10 },
		{ 58,7,11,19 } };
		private static int[,] m_MESSIAH = new int[,] { 
		{ 27,9,25,26 },
		{ 40,11,1,6 },
		{ 40,16,13,17 },
		{ 43,1,41,41 },
		{ 43,4,25,26 } };
		private static int[,] m_PREEXISTENCE = new int[,] { 
		{ 33,5,2,2 },
		{ 43,1,1,2 },
		{ 43,17,5,24 },
		{ 46,10,4,4 },
		{ 50,2,5,8 },
		{ 60,1,10,11 } };
		private static int[,] m_PROPHESIES_OF_MESSIAH = new int[,] { 
		{ 23,7,14,14 },
		{ 23,9,6,7 },
		{ 33,5,2,5 },
		{ 38,6,12,13 } };
		private static int[,] m_RESURRECTION_OF_MESSIAH = new int[,] { 
		{ 19,16,9,10 },
		{ 40,12,38,40 },
		{ 42,24,1,6 },
		{ 43,2,18,22 },
		{ 43,20,11,18 },
		{ 44,1,1,3 } };
		private static int[,] m_RETURN_OF_MESSIAH = new int[,] { 
		{ 38,14,3,5 },
		{ 40,24,29,31 },
		{ 44,1,9,11 },
		{ 52,4,13,17 },
		{ 66,1,7,7 },
		{ 66,11,15,15 } };
		private static int[,] m_SAVIOR = new int[,] { 
		{ 43,1,29,29 },
		{ 43,10,17,18 },
		{ 44,4,12,12 },
		{ 45,5,6,10 },
		{ 46,5,7,7 },
		{ 58,10,10,12 } };
		private static int[,] m_JOY = new int[,] { 
		{ 19,16,11,11 },
		{ 19,30,4,5 },
		{ 40,13,20,21 },
		{ 40,25,21,21 },
		{ 43,15,11,11 },
		{ 43,17,13,13 },
		{ 48,5,22,23 },
		{ 59,1,2,4 } };
		private static int[,] m_JUBILEE = new int[,] { 
		{ 3,23,15,16 },
		{ 3,25,1,7 },
		{ 3,25,8,17 },
		{ 3,25,23,34 },
		{ 3,25,39,55 },
		{ 3,27,16,24 },
		{ 23,61,1,3 },
		{ 42,4,16,21 } };
		private static int[,] m_JUDAH = new int[,] { 
		{ 1,29,32,35 },
		{ 11,12,17,20 },
		{ 38,12,1,9 },
		{ 45,2,28,29 },
		{ 45,3,1,2 },
		{ 46,9,19,20 },
		{ 48,3,26,29 },
		{ 58,8,7,13 },
		{ 16,13,15,18 },
		{ 24,24,3,5 },
		{ 24,39,1,2 },
		{ 26,37,16,25 } };
		private static int[,] m_JUDGMENT_OF_GOD = new int[,] { 
		{ 9,16,7,7 },
		{ 21,3,17,17 },
		{ 44,10,42,42 },
		{ 46,5,12,13 },
		{ 58,9,27,27 },
		{ 60,4,17,17 } };
		private static int[,] m_JUDGMENT_OF_MAN = new int[,] { 
		{ 3,19,15,16 },
		{ 9,16,7,7 },
		{ 40,7,1,5 },
		{ 45,14,4,12 },
		{ 46,6,1,3 },
		{ 46,11,31,31 } };
		private static int[,] m_JURY_DUTY = new int[,] { 
		{ 40,6,14,15 },
		{ 40,7,1,1 },
		{ 42,12,13,14 },
		{ 43,7,24,24 },
		{ 45,14,23,23 },
		{ 46,5,12,13 },
		{ 47,5,20,20 },
		{ 47,6,14,18 } };
		private static int[,] m_JUSTICE = new int[,] { 
		{ 2,21,23,25 },
		{ 3,19,35,37 },
		{ 23,30,18,18 },
		{ 23,42,1,1 },
		{ 27,4,37,37 },
		{ 38,7,9,10 },
		{ 40,12,18,21 },
		{ 44,24,15,15 } };
		private static int[,] m_JUSTIFICATION = new int[,] { 
		{ 45,2,13,13 },
		{ 45,3,20,28 },
		{ 45,3,24,24 },
		{ 45,4,23,25 },
		{ 45,8,30,30 },
		{ 48,2,16,16 },
		{ 48,3,8,8 },
		{ 56,3,7,7 } };
		private static int[,] m_KILL = new int[,] { 
		{ 1,4,8,15 },
		{ 2,20,13,13 },
		{ 21,3,1,3 },
		{ 40,5,21,24 },
		{ 43,10,7,18 },
		{ 59,2,8,11 },
		{ 62,3,14,15 },
		{ 66,22,14,15 } };
		private static int[,] m_KINDNESS = new int[,] { 
		{ 19,117,1,2 },
		{ 20,31,26,26 },
		{ 24,9,23,24 },
		{ 48,5,22,23 },
		{ 49,2,4,7 },
		{ 51,3,12,13 },
		{ 56,3,4,5 },
		{ 61,1,5,7 } };
		private static int[,] m_KING = new int[,] { 
		{ 5,17,14,20 },
		{ 9,15,17,23 },
		{ 26,37,24,24 },
		{ 42,1,30,33 },
		{ 54,6,15,15 },
		{ 66,5,10,10 } };
		private static int[,] m_KINGDOM_OF_GOD = new int[,] { 
		{ 27,2,44,44 },
		{ 40,6,33,33 },
		{ 41,1,14,15 },
		{ 42,9,62,62 },
		{ 43,3,1,8 },
		{ 43,18,36,36 },
		{ 45,14,17,17 },
		{ 46,15,50,50 } };
		private static int[,] m_KNOWLEDGE = new int[,] { 
		{ 20,1,7,7 },
		{ 21,12,12,12 },
		{ 23,11,9,9 },
		{ 27,12,4,4 },
		{ 28,4,6,6 },
		{ 54,6,20,21 },
		{ 55,3,6,7 },
		{ 61,3,18,18 } };
		private static int[,] m_LABOR = new int[,] { 
		{ 20,14,23,23 },
		{ 21,5,18,20 },
		{ 21,9,10,10 },
		{ 40,11,28,30 },
		{ 40,20,1,16 },
		{ 49,4,28,28 },
		{ 52,4,9,12 },
		{ 53,3,10,12 } };
		private static int[,] m_LAST_DAYS = new int[,] { 
		{ 1,49,1,1 },
		{ 23,2,2,4 },
		{ 27,2,28,28 },
		{ 27,12,8,10 },
		{ 28,3,4,5 },
		{ 40,24,3,14 },
		{ 46,15,24,25 },
		{ 55,3,1,5 } };
		private static int[,] m_LAW = new int[,] { 
		{ 19,119,165,16 },
		{ 20,3,1,2 },
		{ 40,5,17,19 },
		{ 45,4,15,15 },
		{ 45,7,7,12 },
		{ 45,8,7,7 },
		{ 45,10,4,4 },
		{ 48,3,19,19 } };
		private static int[,] m_LAYING_ON_OF_HANDS = new int[,] { 
		{ 1,27,18,29 },
		{ 1,48,14,16 },
		{ 3,24,10,16 },
		{ 41,10,13,16 },
		{ 44,8,14,17 },
		{ 44,8,18,24 },
		{ 44,19,5,6 },
		{ 58,6,1,2 } };
		private static int[,] m_CONSECRATION = new int[,] { 
		{ 4,8,10,11 },
		{ 4,27,22,23 },
		{ 44,6,1,6 },
		{ 44,13,1,3 },
		{ 54,4,14,14 },
		{ 54,5,22,22 } };
		private static int[,] m_HEALING_TOUCH = new int[,] { 
		{ 41,5,23,23 },
		{ 41,6,13,13 },
		{ 41,8,22,26 },
		{ 41,16,18,18 },
		{ 42,13,11,13 },
		{ 59,5,13,15 } };
		private static int[,] m_LEADERSHIP = new int[,] { 
		{ 23,55,3,4 },
		{ 24,23,1,1 },
		{ 40,15,14,14 },
		{ 41,9,33,35 },
		{ 41,10,42,45 },
		{ 43,10,11,18 },
		{ 46,11,1,1 },
		{ 49,6,9,9 } };
		private static int[,] m_LETHARGY = new int[,] { 
		{ 20,6,6,11 },
		{ 20,12,24,24 },
		{ 20,13,4,4 },
		{ 20,24,30,34 },
		{ 20,26,13,16 },
		{ 40,25,1,13 },
		{ 42,21,34,36 },
		{ 66,3,14,22 } };
		private static int[,] m_LEVI = new int[,] { 
		{ 2,6,16,16 },
		{ 2,32,25,29 },
		{ 4,3,5,9 },
		{ 4,3,12,13 },
		{ 4,18,21,24 },
		{ 5,14,27,29 },
		{ 13,15,2,2 },
		{ 58,7,11,12 } };
		private static int[,] m_LIE = new int[,] { 
		{ 2,20,16,16 },
		{ 20,11,1,1 },
		{ 40,15,18,20 },
		{ 45,3,4,4 },
		{ 49,4,25,25 },
		{ 51,3,9,10 },
		{ 66,21,27,27 },
		{ 66,22,14,15 } };
		private static int[,] m_LIVING_WATER = new int[,] { 
		{ 23,55,1,1 },
		{ 40,5,6,6 },
		{ 43,4,5,15 },
		{ 43,6,35,35 },
		{ 43,7,37,39 },
		{ 66,7,13,17 },
		{ 66,21,6,6 },
		{ 66,22,1,2 } };
		private static int[,] m_LONGSUFFERING = new int[,] { 
		{ 2,34,6,7 },
		{ 46,13,4,7 },
		{ 48,5,22,23 },
		{ 49,4,1,2 },
		{ 51,1,9,11 },
		{ 54,1,16,16 },
		{ 60,3,18,20 },
		{ 61,3,9,14 } };
		private static int[,] m_LOVE = new int[,] { 
		{ 5,6,5,5 },
		{ 43,3,16,16 },
		{ 43,15,12,13 },
		{ 45,13,8,10 },
		{ 48,5,22,23 },
		{ 62,4,16,19 },
		{ 62,5,2,3 } };
		private static int[,] m_LUST = new int[,] { 
		{ 1,3,6,6 },
		{ 18,31,9,12 },
		{ 20,6,20,29 },
		{ 40,5,28,28 },
		{ 43,8,44,44 },
		{ 59,1,13,15 },
		{ 59,4,1,2 },
		{ 60,2,11,12 } };
		private static int[,] m_MAN = new int[,] { 
		{ 1,1,26,28 },
		{ 1,2,18,24 },
		{ 19,139,13,16 },
		{ 46,15,39,39 },
		{ 46,15,45,49 },
		{ 46,15,50,54 },
		{ 56,2,1,2 },
		{ 58,2,6,8 } };
		private static int[,] m_NATURE_OF_MAN = new int[,] { 
		{ 20,16,2,25 },
		{ 21,7,29,29 },
		{ 24,10,23,23 },
		{ 24,17,9,9 },
		{ 48,5,19,21 },
		{ 49,2,1,3 } };
		private static int[,] m_MARRIAGE = new int[,] { 
		{ 1,2,18,18 },
		{ 39,2,14,15 },
		{ 40,22,23,30 },
		{ 41,10,6,9 },
		{ 49,5,22,33 },
		{ 46,11,3,3 },
		{ 47,6,14,14 } };
		private static int[,] m_HUSBAND = new int[,] { 
		{ 1,2,18,25 },
		{ 5,24,5,5 },
		{ 20,5,15,19 },
		{ 46,7,11,16 },
		{ 49,5,25,28 },
		{ 60,3,7,7 } };
		private static int[,] m_WIFE = new int[,] { 
		{ 20,19,14,14 },
		{ 20,31,10,31 },
		{ 46,7,10,11 },
		{ 49,5,22,24 },
		{ 60,3,1,2 },
		{ 60,3,3,6 } };
		private static int[,] m_MARRIAGE_OF_THE_LAMB = new int[,] { 
		{ 26,16,8,8 },
		{ 40,22,1,14 },
		{ 40,25,1,13 },
		{ 40,26,29,29 },
		{ 42,13,29,29 },
		{ 42,22,14,16 },
		{ 49,5,31,33 },
		{ 66,19,6,9 } };
		private static int[,] m_BRIDE_OF_CHRIST = new int[,] { 
		{ 28,2,16,20 },
		{ 47,11,2,2 },
		{ 49,5,22,24 },
		{ 60,3,1,6 },
		{ 66,21,9,9 },
		{ 66,22,17,17 } };
		private static int[,] m_MARTYRDOM = new int[,] { 
		{ 27,7,23,25 },
		{ 40,23,29,36 },
		{ 44,22,19,21 },
		{ 58,11,35,38 },
		{ 66,2,13,13 },
		{ 66,6,9,11 },
		{ 66,16,4,6 },
		{ 66,17,6,6 } };
		private static int[,] m_MEDICINE = new int[,] { 
		{ 20,17,22,22 },
		{ 20,31,6,7 },
		{ 23,38,21,21 },
		{ 23,47,12,12 },
		{ 24,8,21,22 },
		{ 24,30,12,13 },
		{ 24,46,11,12 },
		{ 42,10,33,34 } };
		private static int[,] m_MEDITATION = new int[,] { 
		{ 6,1,8,8 },
		{ 19,1,1,2 },
		{ 19,5,1,3 },
		{ 19,19,14,14 },
		{ 19,119,15,16 },
		{ 20,23,7,7 },
		{ 50,4,8,8 },
		{ 54,4,15,15 } };
		private static int[,] m_MERCY = new int[,] { 
		{ 2,33,19,19 },
		{ 33,6,8,8 },
		{ 40,5,7,7 },
		{ 40,9,13,13 },
		{ 40,23,23,23 },
		{ 47,1,3,3 },
		{ 49,2,4,7 },
		{ 59,2,13,13 } };
		private static int[,] m_MILITARY_SERVICE = new int[,] { 
		{ 2,20,13,13 },
		{ 5,28,1,2 },
		{ 9,17,47,47 },
		{ 40,26,52,52 },
		{ 44,5,29,29 },
		{ 44,10,1,1 },
		{ 46,7,21,24 } };
		private static int[,] m_MILLENNIUM = new int[,] { 
		{ 23,2,1,4 },
		{ 23,11,6,9 },
		{ 23,61,4,7 },
		{ 30,9,13,15 },
		{ 33,4,1,5 },
		{ 38,14,16,19 },
		{ 66,20,1,3 },
		{ 66,20,4,10 } };
		private static int[,] m_MINISTRY = new int[,] { 
		{ 45,13,1,7 },
		{ 46,12,5,5 },
		{ 47,5,18,20 },
		{ 49,4,11,12 },
		{ 54,1,12,12 },
		{ 55,4,1,5 },
		{ 55,4,11,11 },
		{ 58,1,5,7 } };
		private static int[,] m_MODESTY = new int[,] { 
		{ 1,3,21,21 },
		{ 17,1,10,12 },
		{ 18,32,4,9 },
		{ 20,31,30,31 },
		{ 23,3,16,17 },
		{ 46,12,23,24 },
		{ 54,2,8,10 },
		{ 60,3,3,6 } };
		private static int[,] m_MONEY = new int[,] { 
		{ 5,8,18,18 },
		{ 20,28,20,20 },
		{ 20,30,7,9 },
		{ 40,6,19,21 },
		{ 40,19,23,24 },
		{ 49,4,28,28 },
		{ 54,6,9,10 },
		{ 59,5,1,5 } };
		private static int[,] m_MOTHER = new int[,] { 
		{ 1,2,23,24 },
		{ 1,3,20,20 },
		{ 2,20,12,12 },
		{ 20,1,8,9 },
		{ 20,10,1,1 },
		{ 20,20,20,20 },
		{ 40,15,3,6 },
		{ 42,14,26,27 } };
		private static int[,] m_MUSIC = new int[,] { 
		{ 1,4,21,21 },
		{ 10,6,3,5 },
		{ 18,30,31,31 },
		{ 18,38,7,7 },
		{ 30,6,3,7 },
		{ 36,3,17,17 },
		{ 66,5,8,10 },
		{ 66,15,2,4 } };
		private static int[,] m_MUSIC_IN_WORSHIP = new int[,] { 
		{ 2,15,1,1 },
		{ 14,29,25,30 },
		{ 19,33,1,3 },
		{ 19,81,1,2 },
		{ 19,150,1,6 },
		{ 66,14,1,3 } };
		private static int[,] m_NATIONS = new int[,] { 
		{ 1,11,5,9 },
		{ 3,20,24,26 },
		{ 5,32,7,9 },
		{ 38,14,16,19 },
		{ 44,17,26,27 },
		{ 48,3,26,29 },
		{ 66,5,9,10 } };
		private static int[,] m_NEW_HEAVENS_AND_NEW_EARTH = new int[,] { 
		{ 5,4,19,19 },
		{ 23,51,6,6 },
		{ 23,65,17,19 },
		{ 41,13,31,31 },
		{ 58,2,5,5 },
		{ 58,12,25,27 },
		{ 61,3,10,13 },
		{ 66,21,1,1 } };
		private static int[,] m_NEW_MOONS = new int[,] { 
		{ 4,10,10,10 },
		{ 9,20,5,5 },
		{ 15,3,1,5 },
		{ 23,1,12,15 },
		{ 23,66,22,23 },
		{ 28,2,10,11 },
		{ 30,8,1,6 },
		{ 51,2,16,17 } };
		private static int[,] m_NIGHT_TO_BE_MUCH_OBSERVED = new int[,] { 
		{ 2,12,21,22 },
		{ 2,12,35,36 },
		{ 2,12,40,42 },
		{ 2,13,3,4 },
		{ 2,23,14,15 },
		{ 4,33,3,3 },
		{ 5,6,20,25 },
		{ 5,16,1,1 } };
		private static int[,] m_OATHS = new int[,] { 
		{ 5,23,21,23 },
		{ 19,15,1,4 },
		{ 19,50,14,14 },
		{ 24,11,1,5 },
		{ 40,5,33,37 },
		{ 40,23,16,22 },
		{ 44,18,18,18 } };
		private static int[,] m_OBEDIENCE = new int[,] { 
		{ 1,26,4,5 },
		{ 6,24,15,15 },
		{ 9,15,22,23 },
		{ 40,19,17,17 },
		{ 42,6,46,46 },
		{ 44,5,32,32 },
		{ 47,10,3,6 },
		{ 59,1,22,22 } };
		private static int[,] m_OFFERINGS = new int[,] { 
		{ 2,35,4,29 },
		{ 5,16,16,17 },
		{ 9,15,22,22 },
		{ 39,3,8,12 },
		{ 40,5,23,24 },
		{ 42,21,1,4 },
		{ 45,15,25,28 },
		{ 47,9,6,7 } };
		private static int[,] m_OVERCOMING = new int[,] { 
		{ 40,5,48,48 },
		{ 43,16,33,33 },
		{ 45,12,21,21 },
		{ 47,10,3,6 },
		{ 50,1,6,6 },
		{ 61,1,5,10 },
		{ 61,3,17,18 },
		{ 66,2,7,11 } };
		private static int[,] m_PASSOVER = new int[,] { 
		{ 3,23,5,5 },
		{ 4,9,1,3 },
		{ 14,35,1,19 },
		{ 42,22,14,20 },
		{ 43,6,22,58 },
		{ 46,5,7,7 },
		{ 46,11,20,30 },
		{ 4,9,10,12 } };
		private static int[,] m_PATIENCE = new int[,] { 
		{ 19,37,7,11 },
		{ 19,40,1,1 },
		{ 21,7,8,8 },
		{ 25,3,25,27 },
		{ 42,21,19,19 },
		{ 45,15,4,6 },
		{ 58,6,11,15 },
		{ 66,14,12,13 } };
		private static int[,] m_PEACE = new int[,] { 
		{ 19,119,165,16 },
		{ 19,127,1,2 },
		{ 42,2,14,14 },
		{ 45,12,18,18 },
		{ 48,5,22,23 },
		{ 50,4,10,13 },
		{ 51,3,14,15 },
		{ 54,2,1,2 } };
		private static int[,] m_PENTECOST = new int[,] { 
		{ 2,23,14,17 },
		{ 3,23,9,21 },
		{ 4,28,26,31 },
		{ 5,16,9,12 },
		{ 14,8,12,13 },
		{ 44,20,16,16 },
		{ 46,16,8,8 } };
		private static int[,] m_PERSECUTION = new int[,] { 
		{ 19,34,19,22 },
		{ 40,13,18,21 },
		{ 41,10,28,31 },
		{ 45,12,14,14 },
		{ 55,3,12,12 },
		{ 60,4,12,13 },
		{ 66,12,13,13 },
		{ 66,13,1,7 },
		{ 40,26,41,41 },
		{ 45,2,14,14 },
		{ 45,7,14,14 },
		{ 45,8,5,7 },
		{ 46,3,1,4 },
		{ 46,15,39,39 },
		{ 47,10,2,5 },
		{ 48,5,19,21 } };
		private static int[,] m_PHYSICIAN = new int[,] { 
		{ 1,50,1,2 },
		{ 14,16,11,13 },
		{ 24,8,21,22 },
		{ 40,9,12,12 },
		{ 41,5,25,26 },
		{ 42,4,23,23 },
		{ 51,4,14,14 },
		{ 59,5,13,15 } };
		private static int[,] m_PLACE_OF_SAFETY = new int[,] { 
		{ 23,16,1,4 },
		{ 23,33,15,16 },
		{ 26,5,1,3 },
		{ 39,3,17,17 },
		{ 42,21,34,36 },
		{ 66,3,10,10 },
		{ 66,12,13,17 } };
		private static int[,] m_POLITICS = new int[,] { 
		{ 27,4,17,17 },
		{ 43,18,36,36 },
		{ 45,13,1,1 },
		{ 47,5,20,20 },
		{ 49,2,19,19 },
		{ 50,3,20,20 },
		{ 55,2,3,4 },
		{ 66,18,4,4 } };
		private static int[,] m_POOR = new int[,] { 
		{ 3,19,9,10 },
		{ 5,15,7,11 },
		{ 19,112,9,9 },
		{ 20,6,6,11 },
		{ 20,11,24,26 },
		{ 20,13,18,18 },
		{ 23,58,6,7 },
		{ 40,25,31,46 } };
		private static int[,] m_PRAYER = new int[,] { 
		{ 9,12,22,23 },
		{ 23,1,15,15 },
		{ 40,6,5,13 },
		{ 42,18,1,8 },
		{ 52,5,17,17 },
		{ 58,4,16,16 },
		{ 59,4,2,3 },
		{ 59,5,13,18 } };
		private static int[,] m_PREDESTINED = new int[,] { 
		{ 40,20,16,16 },
		{ 49,1,4,5 },
		{ 49,1,7,11 },
		{ 45,4,17,17 },
		{ 45,8,29,30 },
		{ 60,1,20,20 },
		{ 61,1,10,10 },
		{ 66,3,11,11 } };
		private static int[,] m_PREJUDICE = new int[,] { 
		{ 2,23,3,3 },
		{ 5,1,16,17 },
		{ 9,16,7,7 },
		{ 14,19,7,7 },
		{ 20,18,13,13 },
		{ 44,10,34,35 },
		{ 59,2,1,9 },
		{ 59,3,17,17 } };
		private static int[,] m_PRIDE = new int[,] { 
		{ 20,6,16,19 },
		{ 20,13,10,10 },
		{ 20,16,18,18 },
		{ 26,28,17,17 },
		{ 45,1,28,32 },
		{ 48,6,3,3 },
		{ 55,3,1,5 },
		{ 60,5,5,5 } };
		private static int[,] m_PRIEST = new int[,] { 
		{ 2,40,12,15 },
		{ 6,18,7,7 },
		{ 14,19,11,11 },
		{ 26,44,23,23 },
		{ 58,4,14,14 },
		{ 60,2,5,9 },
		{ 66,1,4,6 },
		{ 66,20,6,6 } };
		private static int[,] m_THE_PROMISE = new int[,] { 
		{ 1,12,1,3 },
		{ 44,2,38,39 },
		{ 48,3,29,29 },
		{ 56,1,1,2 },
		{ 45,4,13,13 },
		{ 58,9,15,15 },
		{ 58,11,13,39 },
		{ 61,3,13,13 } };
		private static int[,] m_PROPHECY = new int[,] { 
		{ 30,3,7,7 },
		{ 40,26,56,56 },
		{ 46,12,4,11 },
		{ 46,13,2,2 },
		{ 61,1,19,21 },
		{ 66,1,1,1 },
		{ 66,19,9,10 },
		{ 66,22,18,19 } };
		private static int[,] m_PROPHETS = new int[,] { 
		{ 5,18,15,22 },
		{ 30,3,7,7 },
		{ 42,16,16,16 },
		{ 42,24,19,19 },
		{ 46,12,28,28 },
		{ 61,1,20,21 } };
		private static int[,] m_REBELLION = new int[,] { 
		{ 5,21,18,21 },
		{ 4,14,1,45 },
		{ 4,20,10,11 },
		{ 9,15,22,23 },
		{ 11,12,19,19 },
		{ 20,17,11,11 } };
		private static int[,] m_RECONCILIATION = new int[,] { 
		{ 40,5,21,26 },
		{ 40,5,38,42 },
		{ 40,5,43,48 },
		{ 40,18,15,17 },
		{ 45,5,10,11 },
		{ 45,12,18,18 },
		{ 46,7,10,11 },
		{ 47,5,18,20 } };
		private static int[,] m_REDEMPTION = new int[,] { 
		{ 3,27,3,3 },
		{ 19,19,14,14 },
		{ 42,21,27,28 },
		{ 46,6,19,20 },
		{ 48,4,4,5 },
		{ 58,9,11,15 },
		{ 60,1,17,19 },
		{ 66,5,9,10 } };
		private static int[,] m_REJOICE = new int[,] { 
		{ 5,14,23,26 },
		{ 5,16,13,15 },
		{ 19,98,4,6 },
		{ 20,5,15,18 },
		{ 20,29,2,2 },
		{ 21,11,9,10 },
		{ 46,13,4,6 },
		{ 60,1,6,9 } };
		private static int[,] m_REPENTANCE = new int[,] { 
		{ 40,3,5,10 },
		{ 40,4,17,17 },
		{ 44,2,38,39 },
		{ 45,2,4,4 },
		{ 45,12,1,2 },
		{ 47,7,8,11 },
		{ 61,3,9,9 } };
		private static int[,] m_RESURRECTION = new int[,] { 
		{ 18,14,13,15 },
		{ 27,12,1,3 },
		{ 40,22,30,30 },
		{ 40,22,31,32 },
		{ 43,5,28,29 },
		{ 43,11,17,27 },
		{ 44,24,15,15 },
		{ 58,9,27,27 },
		{ 23,60,1,3 },
		{ 42,17,20,37 },
		{ 43,6,44,44 },
		{ 52,4,13,17 },
		{ 66,20,6,6 } };
		private static int[,] m_REWARD = new int[,] { 
		{ 40,5,12,12 },
		{ 40,6,5,5 },
		{ 40,25,14,30 },
		{ 42,19,11,27 },
		{ 46,3,8,8 },
		{ 51,2,18,19 },
		{ 66,22,12,12 } };
		private static int[,] m_RIGHTEOUSNESS = new int[,] { 
		{ 19,32,2,2 },
		{ 19,97,2,2 },
		{ 19,119,172,17 },
		{ 23,57,1,2 },
		{ 23,64,6,6 },
		{ 26,18,26,28 },
		{ 40,5,6,6 },
		{ 45,4,1,3 } };
		private static int[,] m_SABBATH = new int[,] { 
		{ 1,2,1,3 },
		{ 2,31,12,17 },
		{ 3,23,1,3 },
		{ 23,66,22,23 },
		{ 41,2,23,28 },
		{ 42,4,16,16 },
		{ 51,2,16,17 },
		{ 58,4,1,10 } };
		private static int[,] m_PREPARATION_FOR_SABBATH = new int[,] { 
		{ 2,16,5,5 },
		{ 2,16,22,22 },
		{ 40,27,62,62 },
		{ 41,15,42,42 },
		{ 42,23,54,54 },
		{ 43,19,31,31 } };
		private static int[,] m_VIOLATION_OF_SABBATH = new int[,] { 
		{ 2,16,23,31 },
		{ 4,15,32,36 },
		{ 16,13,15,22 },
		{ 23,58,13,14 },
		{ 26,20,18,24 },
		{ 30,8,1,6 } };
		private static int[,] m_SACRIFICES = new int[,] { 
		{ 5,15,19,23 },
		{ 9,15,22,22 },
		{ 23,66,3,4 },
		{ 24,7,22,22 },
		{ 26,40,38,43 },
		{ 38,14,20,21 },
		{ 58,9,6,10 },
		{ 58,10,3,4 } };
		private static int[,] m_SPIRITUAL_SACRIFICES = new int[,] { 
		{ 19,4,4,5 },
		{ 19,51,17,17 },
		{ 19,116,16,17 },
		{ 45,12,1,1 },
		{ 58,10,12,12 },
		{ 60,2,5,5 } };
		private static int[,] m_SAINT = new int[,] { 
		{ 19,149,5,9 },
		{ 27,7,18,18 },
		{ 45,15,25,26 },
		{ 46,1,2,2 },
		{ 49,4,11,12 },
		{ 53,1,10,10 },
		{ 66,14,12,12 } };
		private static int[,] m_SALVATION = new int[,] { 
		{ 40,10,22,22 },
		{ 44,4,11,12 },
		{ 45,5,10,10 },
		{ 46,1,18,18 },
		{ 47,6,1,2 },
		{ 49,2,8,9 },
		{ 50,2,12,13 },
		{ 54,2,3,4 } };
		private static int[,] m_SANCTIFICATION = new int[,] { 
		{ 26,37,28,28 },
		{ 43,17,17,17 },
		{ 46,1,30,30 },
		{ 46,7,14,14 },
		{ 49,5,25,27 },
		{ 52,4,3,3 },
		{ 53,2,13,13 },
		{ 58,2,11,11 } };
		private static int[,] m_SATAN = new int[,] { 
		{ 23,14,12,15 },
		{ 26,28,12,17 },
		{ 40,4,1,11 },
		{ 43,8,44,44 },
		{ 47,4,3,4 },
		{ 47,11,13,15 },
		{ 49,2,1,2 },
		{ 60,5,8,8 } };
		private static int[,] m_SATANIC_PROPHESIES = new int[,] { 
		{ 1,3,14,15 },
		{ 61,2,4,9 },
		{ 65,1,6,13 },
		{ 66,20,1,3 },
		{ 66,20,7,10 } };
		private static int[,] m_PROTECTION_FROM_SATAN = new int[,] { 
		{ 18,1,6,12 },
		{ 40,6,9,13 },
		{ 42,9,1,1 },
		{ 42,10,17,20 },
		{ 42,22,31,32 },
		{ 59,4,7,8 } };
		private static int[,] m_SCEPTER_PROMISES = new int[,] { 
		{ 1,35,11,11 },
		{ 1,38,24,30 },
		{ 1,49,8,10 },
		{ 10,7,12,16 },
		{ 13,5,1,2 },
		{ 24,33,17,18 },
		{ 24,41,10,10 },
		{ 28,3,4,5 } };
		private static int[,] m_SCRIPTURE = new int[,] { 
		{ 23,8,16,17 },
		{ 42,24,44,45 },
		{ 45,3,1,2 },
		{ 46,10,11,11 },
		{ 55,3,14,17 },
		{ 55,4,11,13 },
		{ 58,1,1,2 },
		{ 61,3,15,16 } };
		private static int[,] m_LAKE_OF_FIRE = new int[,] { 
		{ 19,112,9,10 },
		{ 23,65,20,20 },
		{ 39,4,1,3 },
		{ 40,25,29,30 },
		{ 42,19,26,27 },
		{ 43,5,28,29 },
		{ 58,10,26,31 },
		{ 66,20,13,15 } };
		private static int[,] m_SELF = new int[,] { 
		{ 7,21,25,25 },
		{ 23,14,12,15 },
		{ 45,2,7,8 },
		{ 48,5,19,21 },
		{ 55,3,1,5 },
		{ 56,1,7,7 },
		{ 59,3,14,16 },
		{ 61,2,9,11 } };
		private static int[,] m_SELF_CONTROL = new int[,] { 
		{ 20,12,16,16 },
		{ 20,21,17,17 },
		{ 20,25,28,28 },
		{ 45,14,20,21 },
		{ 46,9,24,27 },
		{ 47,10,3,5 },
		{ 48,5,22,23 },
		{ 59,1,19,19 } };
		private static int[,] m_SERVANT = new int[,] { 
		{ 41,9,35,35 },
		{ 41,10,42,45 },
		{ 46,4,1,1 },
		{ 49,6,5,8 },
		{ 50,2,5,8 },
		{ 50,2,25,30 },
		{ 51,3,22,22 },
		{ 55,2,24,25 } };
		private static int[,] m_SEXUALITY_IN_MARRIAGE = new int[,] { 
		{ 1,1,27,28 },
		{ 1,2,18,18 },
		{ 1,2,24,25 },
		{ 20,5,15,19 },
		{ 46,7,1,5 },
		{ 46,7,9,9 },
		{ 58,13,4,4 } };
		private static int[,] m_SHEPHERD = new int[,] { 
		{ 24,23,1,4 },
		{ 24,50,6,7 },
		{ 42,15,4,7 },
		{ 43,10,1,18 },
		{ 43,10,25,29 },
		{ 44,8,32,33 } };
		private static int[,] m_SICKNESS = new int[,] { 
		{ 2,15,22,26 },
		{ 12,20,1,11 },
		{ 19,103,3,3 },
		{ 23,1,5,6 },
		{ 40,24,7,8 },
		{ 54,5,23,23 },
		{ 66,16,2,2 } };
		private static int[,] m_SIGNS_AND_WONDERS = new int[,] { 
		{ 5,6,22,22 },
		{ 40,24,23,24 },
		{ 41,16,17,18 },
		{ 44,2,22,22 },
		{ 44,5,12,12 },
		{ 47,12,12,12 },
		{ 53,2,9,12 },
		{ 58,2,4,4 } };
		private static int[,] m_MIRACLES = new int[,] { 
		{ 40,13,58,58 },
		{ 41,9,38,39 },
		{ 41,16,15,18 },
		{ 44,19,11,12 },
		{ 46,12,7,11 },
		{ 46,14,22,22 } };
		private static int[,] m_SIGNS = new int[,] { 
		{ 1,1,14,14 },
		{ 1,9,8,17 },
		{ 2,31,12,17 },
		{ 23,7,14,14 },
		{ 40,12,38,40 },
		{ 40,24,3,14 } };
		private static int[,] m_SIN = new int[,] { 
		{ 23,59,1,2 },
		{ 45,3,23,23 },
		{ 45,4,15,15 },
		{ 45,6,23,23 },
		{ 45,14,23,23 },
		{ 46,10,13,13 },
		{ 59,4,17,17 },
		{ 62,3,4,4 } };
		private static int[,] m_UNPARDONABLE_SIN = new int[,] { 
		{ 4,15,30,31 },
		{ 41,3,28,29 },
		{ 58,6,4,6 },
		{ 58,10,26,31 },
		{ 61,2,20,22 },
		{ 62,5,16,16 } };
		private static int[,] m_SLAVE = new int[,] { 
		{ 3,25,39,55 },
		{ 5,15,12,18 },
		{ 43,8,31,36 },
		{ 45,6,16,22 },
		{ 46,7,20,24 },
		{ 48,4,4,7 },
		{ 61,2,18,22 } };
		private static int[,] m_SORROW = new int[,] { 
		{ 1,3,16,16 },
		{ 19,30,4,5 },
		{ 19,127,1,2 },
		{ 23,53,1,6 },
		{ 40,24,7,9 },
		{ 47,7,8,11 },
		{ 52,4,13,14 },
		{ 66,21,4,4 } };
		private static int[,] m_SOUL = new int[,] { 
		{ 1,2,7,7 },
		{ 21,3,18,21 },
		{ 23,1,12,15 },
		{ 24,38,17,20 },
		{ 26,18,4,20 },
		{ 40,10,28,28 },
		{ 52,5,23,23 },
		{ 59,5,20,20 } };
		private static int[,] m_SPEECH = new int[,] { 
		{ 20,15,1,2 },
		{ 21,5,6,6 },
		{ 21,10,11,15 },
		{ 40,12,33,37 },
		{ 40,15,11,11 },
		{ 45,12,14,14 },
		{ 51,4,6,6 },
		{ 59,3,1,12 } };
		private static int[,] m_SPIRIT_IN_MAN = new int[,] { 
		{ 1,1,26,27 },
		{ 18,32,8,8 },
		{ 19,146,3,4 },
		{ 21,3,21,21 },
		{ 21,12,7,7 },
		{ 38,12,1,1 },
		{ 45,8,16,16 },
		{ 46,2,11,11 } };
		private static int[,] m_SPIRITUAL_GIFTS = new int[,] { 
		{ 2,35,30,35 },
		{ 44,2,38,39 },
		{ 45,12,6,8 },
		{ 46,14,1,12 },
		{ 49,4,11,13 },
		{ 58,2,4,4 },
		{ 59,1,17,17 } };
		private static int[,] m_STATUTES_AND_JUDGMENTS = new int[,] { 
		{ 1,26,4,5 },
		{ 2,21,23,23 },
		{ 3,18,5,5 },
		{ 3,26,3,4 },
		{ 5,4,1,14 },
		{ 19,19,7,11 },
		{ 39,4,4,4 } };
		private static int[,] m_STEAL = new int[,] { 
		{ 2,20,15,15 },
		{ 19,50,16,18 },
		{ 20,22,22,22 },
		{ 20,29,24,24 },
		{ 40,15,18,20 },
		{ 40,19,16,19 },
		{ 45,13,8,10 },
		{ 49,4,28,28 } };
		private static int[,] m_STEWARDSHIP = new int[,] { 
		{ 20,10,4,5 },
		{ 20,24,3,4 },
		{ 20,27,23,27 },
		{ 40,25,14,30 },
		{ 42,12,35,48 },
		{ 42,14,28,30 },
		{ 42,16,1,13 },
		{ 60,4,10,10 } };
		private static int[,] m_SUFFERING = new int[,] { 
		{ 44,5,41,42 },
		{ 45,8,16,18 },
		{ 46,12,26,26 },
		{ 50,4,12,12 },
		{ 58,5,5,8 },
		{ 60,2,18,24 },
		{ 60,4,12,19 },
		{ 60,5,10,10 } };
		private static int[,] m_SWEAR = new int[,] { 
		{ 2,20,7,7 },
		{ 3,19,12,12 },
		{ 12,2,23,24 },
		{ 20,20,20,20 },
		{ 40,5,22,22 },
		{ 40,5,33,37 },
		{ 40,15,11,19 },
		{ 51,3,8,8 } };
		private static int[,] m_TABERNACLE = new int[,] { 
		{ 2,25,1,2 },
		{ 2,31,1,11 },
		{ 2,40,34,38 },
		{ 4,9,15,16 },
		{ 13,17,1,5 },
		{ 58,8,1,5 },
		{ 58,9,1,5 } };
		private static int[,] m_SPIRITUAL_TABERNACLE = new int[,] { 
		{ 19,61,3,4 },
		{ 19,84,1,2 },
		{ 23,33,20,20 },
		{ 58,9,6,12 },
		{ 61,1,12,15 },
		{ 66,21,3,3 } };
		private static int[,] m_FEAST_OF_TABERNACLES = new int[,] { 
		{ 2,23,14,17 },
		{ 3,23,33,43 },
		{ 38,14,16,19 },
		{ 40,17,1,9 },
		{ 43,7,2,10 },
		{ 43,7,37,39 },
		{ 44,18,21,21 },
		{ 66,20,4,6 } };
		private static int[,] m_TAXES = new int[,] { 
		{ 2,30,12,16 },
		{ 16,10,32,33 },
		{ 40,17,24,27 },
		{ 40,22,17,21 },
		{ 42,2,1,3 },
		{ 42,5,27,32 },
		{ 45,13,1,7 },
		{ 60,2,13,17 } };
		private static int[,] m_TEACH = new int[,] { 
		{ 5,6,4,7 },
		{ 23,8,20,20 },
		{ 23,30,19,21 },
		{ 40,28,18,20 },
		{ 43,14,25,26 },
		{ 44,8,27,35 },
		{ 54,2,11,12 },
		{ 58,5,12,14 } };
		private static int[,] m_TEMPLE = new int[,] { 
		{ 11,5,8,1 },
		{ 13,22,26,28 },
		{ 14,3,7,2 },
		{ 15,3,8,13 },
		{ 26,40,48,48 },
		{ 40,23,16,22 },
		{ 40,24,1,2 },
		{ 44,2,46,47 } };
		private static int[,] m_SPIRITUAL_TEMPLE = new int[,] { 
		{ 39,3,1,1 },
		{ 43,2,19,21 },
		{ 46,3,16,16 },
		{ 49,2,19,22 },
		{ 60,2,5,5 },
		{ 66,21,22,22 } };
		private static int[,] m_THANKFULNESS = new int[,] { 
		{ 19,95,2,2 },
		{ 19,116,17,17 },
		{ 47,2,14,14 },
		{ 49,1,15,16 },
		{ 49,5,18,20 },
		{ 50,4,6,6 },
		{ 52,1,2,2 },
		{ 52,5,18,18 } };
		private static int[,] m_THRONE = new int[,] { 
		{ 23,14,12,14 },
		{ 23,48,1,2 },
		{ 40,19,28,28 },
		{ 66,20,4,4 },
		{ 66,20,11,11 },
		{ 66,22,3,5 } };
		private static int[,] m_TIME = new int[,] { 
		{ 1,1,3,5 },
		{ 1,1,14,18 },
		{ 3,23,32,32 },
		{ 23,9,6,7 },
		{ 43,1,1,1 },
		{ 48,4,4,5 },
		{ 56,1,1,3 },
		{ 61,3,8,8 } };
		private static int[,] m_TITHES = new int[,] { 
		{ 3,27,30,33 },
		{ 5,16,16,17 },
		{ 39,3,8,12 },
		{ 40,22,21,21 },
		{ 40,23,23,23 },
		{ 42,18,10,14 },
		{ 47,9,6,7 },
		{ 58,7,1,12 } };
		private static int[,] m_FIRST_TITHES = new int[,] { 
		{ 1,14,18,20 },
		{ 1,28,20,22 },
		{ 4,18,21,24 },
		{ 4,18,25,28 },
		{ 5,14,22,22 },
		{ 16,12,44,47 } };
		private static int[,] m_SECOND_TITHES = new int[,] { 
		{ 5,12,5,12 },
		{ 5,12,17,18 },
		{ 5,14,23,26 },
		{ 5,14,27,27 },
		{ 5,16,10,14 },
		{ 16,8,10,12 } };
		private static int[,] m_THIRD_TITHES = new int[,] { 
		{ 5,14,27,29 },
		{ 5,26,12,15 },
		{ 18,31,16,23 },
		{ 19,146,8,9 },
		{ 30,4,4,4 },
		{ 59,1,27,27 } };
		private static int[,] m_TONGUES = new int[,] { 
		{ 1,11,6,9 },
		{ 36,3,8,9 },
		{ 44,2,4,6 },
		{ 44,10,46,46 },
		{ 44,19,6,6 },
		{ 46,12,7,10 },
		{ 46,13,1,1 } };
		private static int[,] m_TREE_OF_LIFE = new int[,] { 
		{ 1,2,9,9 },
		{ 1,3,22,24 },
		{ 5,30,19,19 },
		{ 19,1,1,3 },
		{ 24,17,7,8 },
		{ 66,2,7,7 },
		{ 66,22,1,2 },
		{ 66,22,14,14 } };
		private static int[,] m_TRIALS = new int[,] { 
		{ 19,34,19,19 },
		{ 44,14,21,22 },
		{ 45,8,18,18 },
		{ 45,8,28,31 },
		{ 46,10,13,13 },
		{ 55,3,12,12 },
		{ 59,1,2,4 },
		{ 60,4,12,12 } };
		private static int[,] m_THE_GREAT_TRIBULATION = new int[,] { 
		{ 27,12,1,1 },
		{ 40,24,9,13 },
		{ 66,3,10,10 },
		{ 66,6,9,11 },
		{ 66,7,13,17 },
		{ 66,12,17,17 },
		{ 66,13,15,15 },
		{ 4,14,34,34 },
		{ 26,4,1,6 } };
		private static int[,] m_JACOBS_TROUBLE = new int[,] { 
		{ 23,44,1,3 },
		{ 24,23,7,8 },
		{ 24,30,5,11 },
		{ 24,31,8,9 },
		{ 24,46,27,28 },
		{ 26,37,15,28 } };
		private static int[,] m_THREE_AND_A_HALF_YEARS = new int[,] { 
		{ 27,7,25,25 },
		{ 27,12,7,7 },
		{ 66,11,1,12 },
		{ 66,12,6,6 },
		{ 66,12,14,14 },
		{ 66,13,4,5 } };
		private static int[,] m_TIMES_OF_THE_GENTILES = new int[,] { 
		{ 27,8,13,14 },
		{ 27,12,11,11 },
		{ 38,14,1,2 },
		{ 38,14,11,11 },
		{ 42,21,23,24 },
		{ 66,11,1,3 } };
		private static int[,] m_FEAST_OF_TRUMPETS = new int[,] { 
		{ 3,23,23,25 },
		{ 4,29,1,1 },
		{ 6,6,1,5 },
		{ 19,81,3,3 },
		{ 24,4,19,21 },
		{ 46,15,51,52 },
		{ 52,4,13,17 },
		{ 66,11,15,15 } };
		private static int[,] m_TRUTH = new int[,] { 
		{ 43,8,31,32 },
		{ 43,17,17,17 },
		{ 45,3,4,4 },
		{ 50,4,8,8 },
		{ 54,3,15,15 },
		{ 55,2,15,15 },
		{ 61,2,1,2 },
		{ 62,3,18,19 } };
		private static int[,] m_FEAST_OF_UNLEAVENEDBREAD = new int[,] { 
		{ 2,12,37,39 },
		{ 2,13,6,10 },
		{ 3,23,6,8 },
		{ 42,22,1,1 },
		{ 44,20,6,6 },
		{ 45,6,4,4 },
		{ 46,5,1,7 },
		{ 46,5,8,8 } };
		private static int[,] m_VANITY = new int[,] { 
		{ 19,39,4,6 },
		{ 19,127,1,2 },
		{ 40,15,8,9 },
		{ 45,8,18,21 },
		{ 46,3,18,20 },
		{ 46,13,1,3 },
		{ 55,2,14,16 } };
		private static int[,] m_WAR = new int[,] { 
		{ 2,14,13,14 },
		{ 2,20,13,13 },
		{ 19,33,16,17 },
		{ 23,2,2,4 },
		{ 40,24,6,6 },
		{ 40,26,51,52 },
		{ 43,18,36,36 },
		{ 59,4,1,2 } };
		private static int[,] m_SPIRITUAL_WAR = new int[,] { 
		{ 40,4,1,11 },
		{ 47,10,3,6 },
		{ 49,2,1,2 },
		{ 49,6,12,12 },
		{ 54,1,18,20 },
		{ 60,5,8,8 } };
		private static int[,] m_WEATHER = new int[,] { 
		{ 1,2,4,6 },
		{ 3,26,3,5 },
		{ 30,4,6,9 },
		{ 40,5,44,45 },
		{ 59,5,17,18 },
		{ 66,7,1,1 },
		{ 66,11,3,6 } };
		private static int[,] m_WHITE_THRONE_OF_JUDGMENT = new int[,] { 
		{ 26,37,1,14 },
		{ 27,12,1,3 },
		{ 40,12,35,42 },
		{ 42,11,31,32 },
		{ 43,12,48,48 },
		{ 61,2,9,9 },
		{ 66,20,5,5 },
		{ 66,20,11,15 } };
		private static int[,] m_WIDOW = new int[,] { 
		{ 2,22,22,24 },
		{ 19,68,5,5 },
		{ 19,146,9,9 },
		{ 44,6,1,1 },
		{ 54,5,3,8 },
		{ 54,5,9,16 },
		{ 59,1,27,27 },
		{ 66,18,7,8 } };
		private static int[,] m_WISDOM = new int[,] { 
		{ 19,14,1,1 },
		{ 19,111,10,10 },
		{ 19,112,5,5 },
		{ 46,1,25,26 },
		{ 46,3,19,19 },
		{ 59,1,5,8 } };
		private static int[,] m_WITCHCRAFT = new int[,] { 
		{ 2,22,18,18 },
		{ 3,20,6,6 },
		{ 5,18,9,14 },
		{ 9,28,3,20 },
		{ 27,2,1,13 },
		{ 44,8,9,13 },
		{ 44,16,16,18 },
		{ 66,22,14,15 } };
		private static int[,] m_WOMAN = new int[,] { 
		{ 1,2,23,23 },
		{ 20,31,30,31 },
		{ 42,1,26,38 },
		{ 44,2,16,18 },
		{ 46,11,3,16 },
		{ 46,14,34,35 },
		{ 54,2,8,15 },
		{ 56,2,3,5 } };
		private static int[,] m_HARLOT = new int[,] { 
		{ 20,9,13,18 },
		{ 26,16,15,63 },
		{ 28,2,2,13 },
		{ 58,11,31,31 } };
		private static int[,] m_VIRGIN = new int[,] { 
		{ 5,22,13,21 },
		{ 26,16,1,14 },
		{ 40,25,1,13 },
		{ 46,7,25,38 },
		{ 66,14,1,5 } };
		private static int[,] m_WORKS = new int[,] { 
		{ 40,6,1,4 },
		{ 40,20,1,16 },
		{ 48,3,10,10 },
		{ 58,6,1,1 },
		{ 59,2,17,20 },
		{ 62,3,18,18 },
		{ 66,2,2,3 },
		{ 66,20,12,12 } };
		private static int[,] m_WORKS_OF_GOD = new int[,] { 
		{ 19,111,2,8 },
		{ 41,6,4,6 },
		{ 43,4,34,34 },
		{ 43,5,17,17 },
		{ 43,9,4,5 },
		{ 49,2,10,10 } };
		private static int[,] m_WORRY = new int[,] { 
		{ 19,37,7,11 },
		{ 40,6,25,34 },
		{ 42,10,38,42 },
		{ 42,12,11,12 },
		{ 42,12,32,32 },
		{ 45,8,28,28 },
		{ 50,4,6,7 },
		{ 60,5,6,7 } };
		private static int[,] m_WORSHIP = new int[,] { 
		{ 2,20,1,11 },
		{ 23,66,22,23 },
		{ 40,4,10,10 },
		{ 43,4,24,24 },
		{ 46,8,4,6 },
		{ 66,3,9,9 },
		{ 66,22,8,9 } };
		private static int[,] m_YOUTH = new int[,] { 
		{ 9,17,42,42 },
		{ 19,25,7,7 },
		{ 19,71,5,17 },
		{ 21,11,9,9 },
		{ 27,1,3,6 },
		{ 40,19,20,20 },
		{ 44,2,17,18 },
		{ 54,4,11,12 } };
		private static int[,] m_ZEAL = new int[,] { 
		{ 9,17,45,49 },
		{ 12,13,18,19 },
		{ 38,8,2,2 },
		{ 43,2,13,17 },
		{ 45,10,1,2 },
		{ 48,4,17,17 },
		{ 55,1,6,6 },
		{ 66,3,19,19 } };
		private static int[,] m_ZION = new int[,] { 
		{ 11,8,1,1 },
		{ 23,2,3,3 },
		{ 29,2,1,2 },
		{ 38,8,3,3 },
		{ 45,9,33,33 },
		{ 45,11,26,27 },
		{ 60,2,6,6 },
		{ 66,14,1,1 } };
		
		private static int[][,] m_Topics = new int[][,] {
			m_ABOMINATION_OF_DESOLATION, m_ADOPTION, m_ADULTERY, m_SPIRITUAL_ADULTERY, m_ALCOHOL, m_ANGEL_OF_THE_LORD, m_ANGELS,
			m_CHERUBIM, m_HORSES, m_SERAPHIM, m_SEVEN_ANGELS, m_TWENTY_FOUR_ELDERS, m_ANGER, m_ANOINTING, m_ANTICHRIST, m_APOSTASY, 
			m_FALSE_PROPHETS, m_FALSE_TEACHERS, m_APOSTLE, m_ARMAGEDDON, m_ARMOR_OF_GOD, m_ATONEMENT, m_BABYLON, m_BAPTISM, m_HOLY_SPIRIT_BAPTISM,
			m_WATER_BAPTISM, m_BEAST, m_BELIEVE, m_BIBLE_STUDY, m_BIRTHRIGHT_PROMISES, m_BLASPHEME, m_BLESSINGS_AND_CURSES, m_BLESSINGS, 
			m_CURSES, m_BLINDED, m_BLOOD_OF_CHRIST, m_BLOOD_OF_FLESH, m_BOOK_OF_LIFE, m_BORN_AGAIN, m_HEBREW_CALENDAR, m_CALLED, 
			m_CAPITAL_PUNISHMENT, m_CARNAL_CHARACTER, m_CHILDREARING, m_DISCIPLINE, m_CHILDREN, m_CHILDREN_OF_GOD, m_CHOSEN, m_CHRISTIAN, 
			m_CHURCH, m_CHURCH_NAME, m_CHURCH_STRUCTURE, m_CIRCUMCISION, m_CLEAN_AND_UNCLEAN_MEAT, m_COMMANDMENTS, m_COMMITMENT, m_COMPASSION, 
			m_CONVERSION, m_CORRECTION, m_COUNSEL, m_COURAGE, m_COVENANT, m_NEW_COVENANT, m_OLD_COVENANT, m_COVET, m_CREATION, m_CROSS, 
			m_DAY_OF_THE_LORD, m_DEACONS, m_DEATH, m_DEBT, m_DECEIVE, m_DELIVERANCE, m_DEMONS, m_PUNISHMENT, m_DEPRESSION, m_DISCIPLE, m_DISFELLOWSHIP, 
			m_DIVISION, m_DIVORCE, m_DOCTRINE, m_DRESS_AND_GROOMING, m_ELDERS, m_ELIJAH, m_ENDURANCE, m_ENEMY, m_IMMORTALITY, m_EVANGELISM, m_EVIL, 
			m_FAITH, m_FAITHFUL, m_FALSE_CHRIST, m_FAMINE, m_FASTING, m_FATHER, m_FEAR, m_FEAR_OF_GOD, m_FEAST, m_FIRSTBORN, m_FIRSTFRUITS, 
			m_FOOT_WASHING, m_FOREKNEW, m_FOREVER, m_FORGIVENESS, m_FORSAKE, m_FRIENDSHIP, m_GLORY, m_GLUTTONY, m_GOD, m_MAJESTY_OF_CHRIST, m_GOSPEL, 
			m_GOSSIP, m_GOVERNMENT_OF_GOD, m_GOVERNMENT_OF_MAN, m_GRACE, m_HARVEST, m_HEALING, m_HEALTH, m_HEART, m_HEAVEN, m_HEAVENLY_SIGNS, m_HEIRS, 
			m_GEHENNA, m_HADES, m_SHEOL, m_HOLIDAYS, m_HOLY, m_HOLY_SPIRIT, m_INDWELLING, m_INSPIRATION, m_HOMOSEXUALITY, m_HONESTY, m_HOPE, 
			m_HOSPITALITY, m_HUMILITY, m_IDOLATRY, m_ISRAEL, m_CHRIST_OF_ISRAEL, m_CREATOR, m_MELCHIZEDEK, m_MESSIAH, m_PREEXISTENCE, 
			m_PROPHESIES_OF_MESSIAH, m_RESURRECTION_OF_MESSIAH, m_RETURN_OF_MESSIAH, m_SAVIOR, m_JOY, m_JUBILEE, m_JUDAH, m_JUDGMENT_OF_GOD, 
			m_JUDGMENT_OF_MAN, m_JURY_DUTY, m_JUSTICE, m_JUSTIFICATION, m_KILL, m_KINDNESS, m_KING, m_KINGDOM_OF_GOD, m_KNOWLEDGE, m_LABOR, m_LAST_DAYS, 
			m_LAW, m_LAYING_ON_OF_HANDS, m_CONSECRATION, m_HEALING_TOUCH, m_LEADERSHIP, m_LETHARGY, m_LEVI, m_LIE, m_LIVING_WATER, m_LONGSUFFERING, 
			m_LOVE, m_LUST, m_MAN, m_NATURE_OF_MAN, m_MARRIAGE, m_HUSBAND, m_WIFE, m_MARRIAGE_OF_THE_LAMB, m_BRIDE_OF_CHRIST, m_MARTYRDOM, m_MEDICINE, 
			m_MEDITATION, m_MERCY, m_MILITARY_SERVICE, m_MILLENNIUM, m_MINISTRY, m_MODESTY, m_MONEY, m_MOTHER, m_MUSIC, m_MUSIC_IN_WORSHIP, m_NATIONS, 
			m_NEW_HEAVENS_AND_NEW_EARTH, m_NEW_MOONS, m_NIGHT_TO_BE_MUCH_OBSERVED, m_OATHS, m_OBEDIENCE, m_OFFERINGS, m_OVERCOMING, 
			m_PASSOVER, m_PATIENCE, m_PEACE, m_PENTECOST, m_PERSECUTION, m_PHYSICIAN, m_PLACE_OF_SAFETY, m_POLITICS, m_POOR, m_PRAYER, m_PREDESTINED, 
			m_PREJUDICE, m_PRIDE, m_PRIEST, m_THE_PROMISE, m_PROPHECY, m_PROPHETS, m_REBELLION, m_RECONCILIATION, m_REDEMPTION, m_REJOICE, 
			m_REPENTANCE, m_RESURRECTION, m_REWARD, m_RIGHTEOUSNESS, m_SABBATH, m_PREPARATION_FOR_SABBATH, m_VIOLATION_OF_SABBATH, 
			m_SACRIFICES, m_SPIRITUAL_SACRIFICES, m_SAINT, m_SALVATION, m_SANCTIFICATION, m_SATAN, m_SATANIC_PROPHESIES, 
			m_PROTECTION_FROM_SATAN, m_SCEPTER_PROMISES, m_SCRIPTURE, m_LAKE_OF_FIRE, m_SELF, m_SELF_CONTROL, m_SERVANT, 
			m_SEXUALITY_IN_MARRIAGE, m_SHEPHERD, m_SICKNESS, m_SIGNS_AND_WONDERS, m_MIRACLES, m_SIGNS, m_SIN, m_UNPARDONABLE_SIN, m_SLAVE, 
			m_SORROW, m_SOUL, m_SPEECH, m_SPIRIT_IN_MAN, m_SPIRITUAL_GIFTS, m_STATUTES_AND_JUDGMENTS, m_STEAL, m_STEWARDSHIP, m_SUFFERING, m_SWEAR, 
			m_TABERNACLE, m_SPIRITUAL_TABERNACLE, m_FEAST_OF_TABERNACLES, m_TAXES, m_TEACH, m_TEMPLE, m_SPIRITUAL_TEMPLE, m_THANKFULNESS, 
			m_THRONE, m_TIME, m_TITHES, m_FIRST_TITHES, m_SECOND_TITHES, m_THIRD_TITHES, m_TONGUES, m_TREE_OF_LIFE, m_TRIALS, 
			m_THE_GREAT_TRIBULATION, m_JACOBS_TROUBLE, m_THREE_AND_A_HALF_YEARS, m_TIMES_OF_THE_GENTILES, m_FEAST_OF_TRUMPETS, 
			m_TRUTH, m_FEAST_OF_UNLEAVENEDBREAD, m_VANITY, m_WAR, m_SPIRITUAL_WAR, m_WEATHER, m_WHITE_THRONE_OF_JUDGMENT, m_WIDOW, m_WISDOM, 
			m_WITCHCRAFT, m_WOMAN, m_HARLOT, m_VIRGIN, m_WORKS, m_WORKS_OF_GOD, m_WORRY, m_WORSHIP, m_YOUTH, m_ZEAL, m_ZION
		};
		
		public static int[] GetTopicVerse( Topic topic, int pick )
		{
			int[] verse = new int[4];
			for ( int x = 0; x < 4; x++ ) verse[x] = GetTopicVerses( topic )[pick,x];
			return verse;
		}
		
		public static int[,] GetTopicVerses( Topic topic )
		{
			return m_Topics[(int)topic];
		}
		
		public static int[] RandomTopicVerse( Topic topic )
		{
			int[] verse = new int[4];
			int[,] verses = m_Topics[(int)topic];
			int length = verses.GetLength( 0 );
			int pick = Utility.Random( length );
			for ( int x = 0; x < 4; x++ ) verse[x] = verses[pick,x];
			return verse;
		}
		
		private static string[] m_TopicNames = new string[] {
			"abomination of desolation","adoption","adultery","spiritual adultery","alcohol","angel of the lord",
			"angels","cherubim","horses","seraphim","seven angels","twenty four elders","anger","anointing",
			"antichrist","apostasy","false prophets","false teachers","apostle","armageddon","armor of god",
			"atonement","babylon","baptism","holy spirit baptism","water baptism","beast","believe","bible study",
			"birthright promises","blaspheme","blessings and curses","blessings","curses","blinded","blood of christ",
			"blood of flesh","book of life","born again","hebrew calendar","called","capital punishment",
			"carnal character","childrearing","discipline","children","children of god","chosen","christian",
			"church","church name","church structure","circumcision","clean and unclean meat","commandments",
			"commitment","compassion","conversion","correction","counsel","courage","covenant","new covenant",
			"old covenant","covet","creation","cross","day of the lord","deacons","death","debt","deceive",
			"deliverance","demons","punishment","depression","disciple","disfellowship","division","divorce",
			"doctrine","dress and grooming","elders","elijah","endurance","enemy","immortality","evangelism",
			"evil","faith","faithful","false christ","famine","fasting","father","fear","fear of god","feast",
			"firstborn","firstfruits","foot washing","foreknew","forever","forgiveness","forsake","friendship",
			"glory","gluttony","god","majesty of christ","gospel","gossip","government of god","government of man",
			"grace","harvest","healing","health","heart","heaven","heavenly signs","heirs","gehenna","hades","sheol",
			"holidays","holy","holy spirit","indwelling","inspiration","homosexuality","honesty","hope","hospitality",
			"humility","idolatry","israel","christ of israel","creator","melchizedek","messiah","preexistence",
			"prophesies of messiah","resurrection of messiah","return of messiah","savior","joy","jubilee","judah",
			"judgment of god","judgment of man","jury duty","justice","justification","kill","kindness","king",
			"kingdom of god","knowledge","labor","last days","law","laying on of hands","consecration","healing touch",
			"leadership","lethargy","levi","lie","living water","longsuffering","love","lust","man","nature of man",
			"marriage","husband","wife","marriage of the lamb","bride of christ","martyrdom","medicine","meditation",
			"mercy","military service","millennium","ministry","modesty","money","mother","music","music in worship",
			"nations","new heavens and new earth","new moons","night to be much observed","oaths","obedience",
			"offerings","overcoming","passover","patience","peace","pentecost","persecution","physician",
			"place of safety","politics","poor","prayer","predestined","prejudice","pride","priest","the promise",
			"prophecy","prophets","rebellion","reconciliation","redemption","rejoice","repentance","resurrection",
			"reward","righteousness","sabbath","preparation for sabbath","violation of sabbath","sacrifices",
			"spiritual sacrifices","saint","salvation","sanctification","satan","satanic prophesies",
			"protection from satan","scepter promises","scripture","lake of fire","self","self control","servant",
			"sexuality in marriage","shepherd","sickness","signs and wonders","miracles","signs","sin",
			"unpardonable sin","slave","sorrow","soul","speech","spirit in man","spiritual gifts",
			"statutes and judgments","steal","stewardship","suffering","swear","tabernacle","spiritual tabernacle",
			"feast of tabernacles","taxes","teach","temple","spiritual temple","thankfulness","throne","time","tithes",
			"first tithes","second tithes","third tithes","tongues","tree of life","trials","the great tribulation",
			"jacobs trouble","three and a half years","times of the gentiles","feast of trumpets","truth",
			"feast of unleavenedbread","vanity","war","spiritual war","weather","white throne of judgment",
			"widow","wisdom","witchcraft","woman","harlot","virgin","works","works of god","worry","worship","youth",
			"zeal","zion"
		};
		
		public static string GetTopicName( Topic topic )
		{
			return m_TopicNames[(int)topic];
		}
	}
}